# coding: utf-8

# flake8: noqa

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.0.2176925439"

# Define package exports
__all__ = [
    "DefaultApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AddUserToWorkspaceRequest",
    "AddWorkspaceMemberRequest",
    "AnalyzeNotebook200Response",
    "AnalyzeNotebook200ResponseSearchResults",
    "AnalyzeNotebook200ResponseSearchResultsMessagesInner",
    "AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner",
    "AnalyzeNotebookRequest",
    "ApiDemosCreateDemoInvitePostRequest",
    "ApiFilesFileIdSignedUrlPost200Response",
    "ApiFilesFileIdSignedUrlPostRequest",
    "ApiInvitesIdParticipantInvitesGet200Response",
    "ApiInvitesIdParticipantInvitesParticipantIdPutRequest",
    "ApiInvitesIdParticipantInvitesPostRequest",
    "ApiInvitesIdParticipantInvitesPostRequestParticipant",
    "ApiInvitesIdPutRequest",
    "ApiInvitesIdResponsesPostRequest",
    "ApiInvitesIdResponsesResponseIdPutRequest",
    "ApiInvitesPostRequest",
    "ApiProjectsPostRequest",
    "ApiProjectsPostRequestThreadAssetsInner",
    "ApiProjectsProjectIdAnalysisPost200Response",
    "ApiProjectsProjectIdAnalysisPostRequest",
    "ApiProjectsProjectIdFilesFileIdPutRequest",
    "ApiProjectsProjectIdFilesGet200Response",
    "ApiProjectsProjectIdFilesPostRequest",
    "ApiProjectsProjectIdPutRequest",
    "ApiProjectsProjectIdSearchTranscriptsPostRequest",
    "ApiThreadsGet200Response",
    "ApiThreadsThreadIdFilesGet200Response",
    "ApiThreadsThreadIdPostRequest",
    "ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response",
    "ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response",
    "ApiThreadsThreadIdProjectBriefVersionsGet200Response",
    "Artifact",
    "ArtifactData",
    "ArtifactDataCreate",
    "ArtifactDataNotNull",
    "ArtifactDataPresentation",
    "ArtifactDataReport",
    "ArtifactDataReportProjectsInner",
    "ArtifactDataSearchResult",
    "ArtifactDataSearchResultTabsInner",
    "ArtifactDataSearchResultTabsInnerMessagesInner",
    "ArtifactDataThematicAnalysis",
    "ArtifactDataThematicAnalysisData",
    "ArtifactDataThematicAnalysisDataThemesInner",
    "ArtifactKind",
    "ArtifactMetadata",
    "ArtifactVersionGroup",
    "AssetAttrs",
    "AssetNode",
    "Attribute",
    "AttributeFilterGroupSchemaInner",
    "AttributeKind",
    "AttributeKindGroup",
    "AttributeKindGroupPurpose",
    "AttributeKindGroupScope",
    "AttributeStatsSchemaInner",
    "AttributeStatsSchemaInnerGroup",
    "AttributeStatsSchemaInnerKind",
    "AttributeStatsSchemaInnerValuesInner",
    "AttributeValueKind",
    "BadRequestErrorResponse",
    "BlockContentNode",
    "BlockquoteNode",
    "BoldMark",
    "BriefDocument",
    "BriefDocumentVersion",
    "BulletListNode",
    "ByoPanelRepdataConfig",
    "Call",
    "CallAnalysis",
    "CallEvent",
    "CallKind",
    "CallMetadata",
    "CallStatus",
    "CallSummary",
    "ChatCompletionTool",
    "ChatCompletionToolFunction",
    "ChatMessage",
    "ChatMessageKind",
    "ChatMessageRole",
    "ChatSession",
    "Citation",
    "CodeInvite",
    "CodeInviteConfig",
    "CodeInviteConfigContacts",
    "CodeInviteConfigKeplarPanel",
    "CodeInviteResponse",
    "CodeMark",
    "ContentNode",
    "ConversationAttrs",
    "ConversationMessage",
    "ConversationMessageTopic",
    "ConversationNode",
    "ConversationStepAttrs",
    "ConversationStepNode",
    "CreateArtifactRequest",
    "CreateCodeInviteResponseRequest",
    "CreateEmailShareRequest",
    "CreateNotebookArtifactRequest",
    "CreateNotebookRequest",
    "CreateOrgRequest",
    "CreateProjectPreviewInvite201Response",
    "CreateProjectPreviewInviteRequest",
    "CreateProjectShareRequest",
    "CreateProjectShareResponse",
    "CreateWorkspaceRequest",
    "DeleteArtifact200Response",
    "DeleteNotebookArtifactVersionGroup200Response",
    "DummyUser",
    "EmailShare",
    "Evidence",
    "FeatureConfig",
    "File",
    "FileMimeType",
    "ForbiddenErrorResponse",
    "GetCodeInvite200Response",
    "GetCodeInviteResponseRedirect200Response",
    "GetOrgMembers200Response",
    "GetOrgs200Response",
    "GetOrgs200ResponseItemsInner",
    "GetOrgs200ResponseItemsInnerDefaultWorkspace",
    "GetOrgs200ResponseItemsInnerStats",
    "GetProjectShares200Response",
    "GetProjects200Response",
    "GetSharedArtifactVersionGroups200Response",
    "GetSharedInviteResponses200Response",
    "GetUserWorkspaces200Response",
    "GetWorkspaceMembers200Response",
    "GetWorkspaces200Response",
    "GetWorkspaces200ResponseItemsInner",
    "HardBreakNode",
    "HeadingAttrs",
    "HeadingNode",
    "ImpersonateUser200Response",
    "ImpersonateUserRequest",
    "ImpersonatedUser",
    "InboundCallResponse",
    "IndexProjectTranscripts200Response",
    "IndexProjectTranscripts200ResponseIndexed",
    "InlineNode",
    "InternalServerErrorResponse",
    "Invite",
    "InviteConfig",
    "InviteConfigByoPanel",
    "InviteConfigContacts",
    "InviteConfigKeplarPanel",
    "InviteConfigPublic",
    "InviteCustomerItem",
    "InviteCustomers201Response",
    "InviteCustomersRequest",
    "InviteOrgResult",
    "InviteResponse",
    "InviteResponseAttribute",
    "InviteResponseAttributeData",
    "InviteResponseData",
    "InviteResponseEvaluationEnum",
    "InviteResponseEvaluationMetadata",
    "InviteResponseKind",
    "InviteResponseMetadata",
    "InviteResponseShareConfig",
    "InviteResponseStatus",
    "InviteResponseUpdateEvent",
    "InviteResponseWithCallSummary",
    "InviteResponseWithMetadata",
    "InviteResponseWithMetadataAttributesInner",
    "InviteResponseWithMetadataAttributesInnerEvidence",
    "InviteStatus",
    "InviteUserRequest",
    "InviteWithAnalytics",
    "InviteWorkspaceResult",
    "InvitedUser",
    "ItalicMark",
    "JoinCodeInvite302Response",
    "JoinCodeInvite302ResponseSettings",
    "LinkMark",
    "LinkMarkAttrs",
    "ListItemNode",
    "Login200Response",
    "Login200ResponseAnyOf",
    "Login400Response",
    "Login400ResponseAnyOf",
    "LoginRequest",
    "Mark",
    "MentionNode",
    "MentionNodeAttrs",
    "Moderator",
    "ModeratorVendor",
    "ModeratorVisibility",
    "NotFoundErrorResponse",
    "Notebook",
    "NotebookArtifactVersionGroup",
    "NotebookArtifactVersionGroupMetadata",
    "NotebookArtifactVersionGroupVisibility",
    "NotebookConfig",
    "NotebookMode",
    "NumberFilterSchema",
    "OpenAiModelConfig",
    "OptionKind",
    "OrderedListAttrs",
    "OrderedListNode",
    "Org",
    "OrgData",
    "OrgDefaultWorkspace",
    "OrgListItem",
    "OrgMember",
    "OrgStats",
    "PanelQualification",
    "PanelRespondentAttribute",
    "PanelSettings",
    "ParagraphNode",
    "Participant",
    "ParticipantAttribute",
    "ParticipantCreate",
    "ParticipantInvite",
    "ParticipantInviteConfig",
    "ParticipantInviteData",
    "PhoneCallStartResponse",
    "PresentationConfig",
    "PresentationConfig1",
    "Project",
    "ProjectAnalysis",
    "ProjectAnalysisReport",
    "ProjectAudience",
    "ProjectBrief",
    "ProjectConfig",
    "ProjectConversationConfig",
    "ProjectFile",
    "ProjectFileCategory",
    "ProjectFileMetadata",
    "ProjectFilePublic",
    "ProjectFilePublicFile",
    "ProjectKind",
    "ProjectShareConfig",
    "ProjectStatus",
    "ProjectSummaryWithAnalytics",
    "ProjectWithAnalytics",
    "RemainingResponsesResponse",
    "RepdataQualification",
    "RepdataQualificationAllowedOptionIdsInner",
    "RepdataRespondentAttribute",
    "RepdataSurvey",
    "RepdataSurveyAttributes",
    "RepdataSurveyRedirects",
    "Report",
    "RequestShareAccess200Response",
    "RequestShareAccessRequest",
    "ResetPasswordRequest",
    "ResponseCallCompletedEvent",
    "ResponseCallFailedEvent",
    "ResponseConsentEvent",
    "ResponseOptOutEvent",
    "ResponseProcessingCompletedEvent",
    "ResponseProcessingFailedEvent",
    "ResponseRedirectEvent",
    "ResponseStartCallEvent",
    "ResponseSubmitEmailEvent",
    "ResponseSubmitScreenerEvent",
    "SaveSearchRequest",
    "SaveSearchRequestTabsInner",
    "ScreenerQuestion",
    "ScreenerQuestionChooseMultiple",
    "ScreenerQuestionChooseMultipleOptionsValue",
    "ScreenerQuestionChooseMultiplePublic",
    "ScreenerQuestionChooseOne",
    "ScreenerQuestionChooseOnePublic",
    "ScreenerQuestionOption",
    "ScreenerQuestionPublic",
    "ScreenerQuestionResponse",
    "SearchProjectTranscriptsResponse",
    "SearchSharedResponseMessages200ResponseInner",
    "SearchSharedResponseMessagesRequest",
    "SearchSharedResponseMessagesRequestInviteResponseMessagesInner",
    "SearchUsers200Response",
    "SearchUsersRequest",
    "SelectFilterSchema",
    "ShareEntity",
    "ShareEntityConfig",
    "ShareEntityCreatedByKind",
    "ShareEntityKind",
    "SignupRequest",
    "SkippedCustomer",
    "StartPhoneCallForCodeInviteResponseRequest",
    "SupportedLanguage",
    "TextNode",
    "ThematicAnalysisArtifactCreateData",
    "ThematicAnalysisArtifactCreateDataThemesInner",
    "ThematicAnalysisArtifactCreateDataThemesInnerCodesInner",
    "ThematicAnalysisResponseCode",
    "ThematicAnalysisResponseCodeCodesInner",
    "ThematicAnalysisResponseCodeCodesInnerEvidence",
    "Thread",
    "ThreadCreateProjectStatus",
    "ThreadFile",
    "ThreadKind",
    "ThreadMetadata",
    "TokenKind",
    "Transcript",
    "TranscriptAttributesInner",
    "TranscriptMessage",
    "TranscriptMessagesInner",
    "TranscriptQuality",
    "TranscriptResponseAttribute",
    "UnauthorizedErrorResponse",
    "UpdateArtifactRequest",
    "UpdateCallForCodeInviteResponseRequest",
    "UpdateCallForCodeInviteResponseRequestCall",
    "UpdateCodeInviteResponse404Response",
    "UpdateNotebookRequest",
    "UpdateNotebookRequestConfig",
    "UpdateNotebookSourcesRequest",
    "UpdateOrg2FARequest",
    "UpdateOrgDefaultWorkspaceRequest",
    "UpdateSearchRequest",
    "UpdateShareEntityRequest",
    "UpdateUserDefaultWorkspace200Response",
    "UpdateUserDefaultWorkspaceRequest",
    "UpdateWorkspaceMemberRequest",
    "UploadCallVideoResponse",
    "User",
    "UserAccountStatus",
    "UserAdminLevel",
    "UserData",
    "UserDefaultWorkspace",
    "UserOrg",
    "UserProject",
    "UserProvider",
    "UserSearchResult",
    "UserWithConfig",
    "UserWorkspaceItem",
    "VapiAssistantConfig",
    "VapiVoiceId",
    "VapiVoiceVapiProvider",
    "VerifyEmailAccessForShare200Response",
    "VerifyEmailAccessForShareRequest",
    "VerifyEmailRequest",
    "VideoRecordingSettings",
    "VideoRecordingStatus",
    "Workspace",
    "WorkspaceListItem",
    "WorkspaceMember",
    "WorkspaceMemberItem",
    "WorkspaceMemberResponse",
    "WorkspaceMemberRole",
    "WorkspaceMemberUser",
]

# import apis into sdk package
from keplar_api.api.default_api import DefaultApi as DefaultApi

# import ApiClient
from keplar_api.api_response import ApiResponse as ApiResponse
from keplar_api.api_client import ApiClient as ApiClient
from keplar_api.configuration import Configuration as Configuration
from keplar_api.exceptions import OpenApiException as OpenApiException
from keplar_api.exceptions import ApiTypeError as ApiTypeError
from keplar_api.exceptions import ApiValueError as ApiValueError
from keplar_api.exceptions import ApiKeyError as ApiKeyError
from keplar_api.exceptions import ApiAttributeError as ApiAttributeError
from keplar_api.exceptions import ApiException as ApiException

# import models into sdk package
from keplar_api.models.add_user_to_workspace_request import AddUserToWorkspaceRequest as AddUserToWorkspaceRequest
from keplar_api.models.add_workspace_member_request import AddWorkspaceMemberRequest as AddWorkspaceMemberRequest
from keplar_api.models.analyze_notebook200_response import AnalyzeNotebook200Response as AnalyzeNotebook200Response
from keplar_api.models.analyze_notebook200_response_search_results import AnalyzeNotebook200ResponseSearchResults as AnalyzeNotebook200ResponseSearchResults
from keplar_api.models.analyze_notebook200_response_search_results_messages_inner import AnalyzeNotebook200ResponseSearchResultsMessagesInner as AnalyzeNotebook200ResponseSearchResultsMessagesInner
from keplar_api.models.analyze_notebook200_response_search_results_messages_inner_context_messages_inner import AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner as AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner
from keplar_api.models.analyze_notebook_request import AnalyzeNotebookRequest as AnalyzeNotebookRequest
from keplar_api.models.api_demos_create_demo_invite_post_request import ApiDemosCreateDemoInvitePostRequest as ApiDemosCreateDemoInvitePostRequest
from keplar_api.models.api_files_file_id_signed_url_post200_response import ApiFilesFileIdSignedUrlPost200Response as ApiFilesFileIdSignedUrlPost200Response
from keplar_api.models.api_files_file_id_signed_url_post_request import ApiFilesFileIdSignedUrlPostRequest as ApiFilesFileIdSignedUrlPostRequest
from keplar_api.models.api_invites_id_participant_invites_get200_response import ApiInvitesIdParticipantInvitesGet200Response as ApiInvitesIdParticipantInvitesGet200Response
from keplar_api.models.api_invites_id_participant_invites_participant_id_put_request import ApiInvitesIdParticipantInvitesParticipantIdPutRequest as ApiInvitesIdParticipantInvitesParticipantIdPutRequest
from keplar_api.models.api_invites_id_participant_invites_post_request import ApiInvitesIdParticipantInvitesPostRequest as ApiInvitesIdParticipantInvitesPostRequest
from keplar_api.models.api_invites_id_participant_invites_post_request_participant import ApiInvitesIdParticipantInvitesPostRequestParticipant as ApiInvitesIdParticipantInvitesPostRequestParticipant
from keplar_api.models.api_invites_id_put_request import ApiInvitesIdPutRequest as ApiInvitesIdPutRequest
from keplar_api.models.api_invites_id_responses_post_request import ApiInvitesIdResponsesPostRequest as ApiInvitesIdResponsesPostRequest
from keplar_api.models.api_invites_id_responses_response_id_put_request import ApiInvitesIdResponsesResponseIdPutRequest as ApiInvitesIdResponsesResponseIdPutRequest
from keplar_api.models.api_invites_post_request import ApiInvitesPostRequest as ApiInvitesPostRequest
from keplar_api.models.api_projects_post_request import ApiProjectsPostRequest as ApiProjectsPostRequest
from keplar_api.models.api_projects_post_request_thread_assets_inner import ApiProjectsPostRequestThreadAssetsInner as ApiProjectsPostRequestThreadAssetsInner
from keplar_api.models.api_projects_project_id_analysis_post200_response import ApiProjectsProjectIdAnalysisPost200Response as ApiProjectsProjectIdAnalysisPost200Response
from keplar_api.models.api_projects_project_id_analysis_post_request import ApiProjectsProjectIdAnalysisPostRequest as ApiProjectsProjectIdAnalysisPostRequest
from keplar_api.models.api_projects_project_id_files_file_id_put_request import ApiProjectsProjectIdFilesFileIdPutRequest as ApiProjectsProjectIdFilesFileIdPutRequest
from keplar_api.models.api_projects_project_id_files_get200_response import ApiProjectsProjectIdFilesGet200Response as ApiProjectsProjectIdFilesGet200Response
from keplar_api.models.api_projects_project_id_files_post_request import ApiProjectsProjectIdFilesPostRequest as ApiProjectsProjectIdFilesPostRequest
from keplar_api.models.api_projects_project_id_put_request import ApiProjectsProjectIdPutRequest as ApiProjectsProjectIdPutRequest
from keplar_api.models.api_projects_project_id_search_transcripts_post_request import ApiProjectsProjectIdSearchTranscriptsPostRequest as ApiProjectsProjectIdSearchTranscriptsPostRequest
from keplar_api.models.api_threads_get200_response import ApiThreadsGet200Response as ApiThreadsGet200Response
from keplar_api.models.api_threads_thread_id_files_get200_response import ApiThreadsThreadIdFilesGet200Response as ApiThreadsThreadIdFilesGet200Response
from keplar_api.models.api_threads_thread_id_post_request import ApiThreadsThreadIdPostRequest as ApiThreadsThreadIdPostRequest
from keplar_api.models.api_threads_thread_id_project_brief_document_versions_get200_response import ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response as ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response
from keplar_api.models.api_threads_thread_id_project_brief_document_versions_version_put200_response import ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response as ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response
from keplar_api.models.api_threads_thread_id_project_brief_versions_get200_response import ApiThreadsThreadIdProjectBriefVersionsGet200Response as ApiThreadsThreadIdProjectBriefVersionsGet200Response
from keplar_api.models.artifact import Artifact as Artifact
from keplar_api.models.artifact_data import ArtifactData as ArtifactData
from keplar_api.models.artifact_data_create import ArtifactDataCreate as ArtifactDataCreate
from keplar_api.models.artifact_data_not_null import ArtifactDataNotNull as ArtifactDataNotNull
from keplar_api.models.artifact_data_presentation import ArtifactDataPresentation as ArtifactDataPresentation
from keplar_api.models.artifact_data_report import ArtifactDataReport as ArtifactDataReport
from keplar_api.models.artifact_data_report_projects_inner import ArtifactDataReportProjectsInner as ArtifactDataReportProjectsInner
from keplar_api.models.artifact_data_search_result import ArtifactDataSearchResult as ArtifactDataSearchResult
from keplar_api.models.artifact_data_search_result_tabs_inner import ArtifactDataSearchResultTabsInner as ArtifactDataSearchResultTabsInner
from keplar_api.models.artifact_data_search_result_tabs_inner_messages_inner import ArtifactDataSearchResultTabsInnerMessagesInner as ArtifactDataSearchResultTabsInnerMessagesInner
from keplar_api.models.artifact_data_thematic_analysis import ArtifactDataThematicAnalysis as ArtifactDataThematicAnalysis
from keplar_api.models.artifact_data_thematic_analysis_data import ArtifactDataThematicAnalysisData as ArtifactDataThematicAnalysisData
from keplar_api.models.artifact_data_thematic_analysis_data_themes_inner import ArtifactDataThematicAnalysisDataThemesInner as ArtifactDataThematicAnalysisDataThemesInner
from keplar_api.models.artifact_kind import ArtifactKind as ArtifactKind
from keplar_api.models.artifact_metadata import ArtifactMetadata as ArtifactMetadata
from keplar_api.models.artifact_version_group import ArtifactVersionGroup as ArtifactVersionGroup
from keplar_api.models.asset_attrs import AssetAttrs as AssetAttrs
from keplar_api.models.asset_node import AssetNode as AssetNode
from keplar_api.models.attribute import Attribute as Attribute
from keplar_api.models.attribute_filter_group_schema_inner import AttributeFilterGroupSchemaInner as AttributeFilterGroupSchemaInner
from keplar_api.models.attribute_kind import AttributeKind as AttributeKind
from keplar_api.models.attribute_kind_group import AttributeKindGroup as AttributeKindGroup
from keplar_api.models.attribute_kind_group_purpose import AttributeKindGroupPurpose as AttributeKindGroupPurpose
from keplar_api.models.attribute_kind_group_scope import AttributeKindGroupScope as AttributeKindGroupScope
from keplar_api.models.attribute_stats_schema_inner import AttributeStatsSchemaInner as AttributeStatsSchemaInner
from keplar_api.models.attribute_stats_schema_inner_group import AttributeStatsSchemaInnerGroup as AttributeStatsSchemaInnerGroup
from keplar_api.models.attribute_stats_schema_inner_kind import AttributeStatsSchemaInnerKind as AttributeStatsSchemaInnerKind
from keplar_api.models.attribute_stats_schema_inner_values_inner import AttributeStatsSchemaInnerValuesInner as AttributeStatsSchemaInnerValuesInner
from keplar_api.models.attribute_value_kind import AttributeValueKind as AttributeValueKind
from keplar_api.models.bad_request_error_response import BadRequestErrorResponse as BadRequestErrorResponse
from keplar_api.models.block_content_node import BlockContentNode as BlockContentNode
from keplar_api.models.blockquote_node import BlockquoteNode as BlockquoteNode
from keplar_api.models.bold_mark import BoldMark as BoldMark
from keplar_api.models.brief_document import BriefDocument as BriefDocument
from keplar_api.models.brief_document_version import BriefDocumentVersion as BriefDocumentVersion
from keplar_api.models.bullet_list_node import BulletListNode as BulletListNode
from keplar_api.models.byo_panel_repdata_config import ByoPanelRepdataConfig as ByoPanelRepdataConfig
from keplar_api.models.call import Call as Call
from keplar_api.models.call_analysis import CallAnalysis as CallAnalysis
from keplar_api.models.call_event import CallEvent as CallEvent
from keplar_api.models.call_kind import CallKind as CallKind
from keplar_api.models.call_metadata import CallMetadata as CallMetadata
from keplar_api.models.call_status import CallStatus as CallStatus
from keplar_api.models.call_summary import CallSummary as CallSummary
from keplar_api.models.chat_completion_tool import ChatCompletionTool as ChatCompletionTool
from keplar_api.models.chat_completion_tool_function import ChatCompletionToolFunction as ChatCompletionToolFunction
from keplar_api.models.chat_message import ChatMessage as ChatMessage
from keplar_api.models.chat_message_kind import ChatMessageKind as ChatMessageKind
from keplar_api.models.chat_message_role import ChatMessageRole as ChatMessageRole
from keplar_api.models.chat_session import ChatSession as ChatSession
from keplar_api.models.citation import Citation as Citation
from keplar_api.models.code_invite import CodeInvite as CodeInvite
from keplar_api.models.code_invite_config import CodeInviteConfig as CodeInviteConfig
from keplar_api.models.code_invite_config_contacts import CodeInviteConfigContacts as CodeInviteConfigContacts
from keplar_api.models.code_invite_config_keplar_panel import CodeInviteConfigKeplarPanel as CodeInviteConfigKeplarPanel
from keplar_api.models.code_invite_response import CodeInviteResponse as CodeInviteResponse
from keplar_api.models.code_mark import CodeMark as CodeMark
from keplar_api.models.content_node import ContentNode as ContentNode
from keplar_api.models.conversation_attrs import ConversationAttrs as ConversationAttrs
from keplar_api.models.conversation_message import ConversationMessage as ConversationMessage
from keplar_api.models.conversation_message_topic import ConversationMessageTopic as ConversationMessageTopic
from keplar_api.models.conversation_node import ConversationNode as ConversationNode
from keplar_api.models.conversation_step_attrs import ConversationStepAttrs as ConversationStepAttrs
from keplar_api.models.conversation_step_node import ConversationStepNode as ConversationStepNode
from keplar_api.models.create_artifact_request import CreateArtifactRequest as CreateArtifactRequest
from keplar_api.models.create_code_invite_response_request import CreateCodeInviteResponseRequest as CreateCodeInviteResponseRequest
from keplar_api.models.create_email_share_request import CreateEmailShareRequest as CreateEmailShareRequest
from keplar_api.models.create_notebook_artifact_request import CreateNotebookArtifactRequest as CreateNotebookArtifactRequest
from keplar_api.models.create_notebook_request import CreateNotebookRequest as CreateNotebookRequest
from keplar_api.models.create_org_request import CreateOrgRequest as CreateOrgRequest
from keplar_api.models.create_project_preview_invite201_response import CreateProjectPreviewInvite201Response as CreateProjectPreviewInvite201Response
from keplar_api.models.create_project_preview_invite_request import CreateProjectPreviewInviteRequest as CreateProjectPreviewInviteRequest
from keplar_api.models.create_project_share_request import CreateProjectShareRequest as CreateProjectShareRequest
from keplar_api.models.create_project_share_response import CreateProjectShareResponse as CreateProjectShareResponse
from keplar_api.models.create_workspace_request import CreateWorkspaceRequest as CreateWorkspaceRequest
from keplar_api.models.delete_artifact200_response import DeleteArtifact200Response as DeleteArtifact200Response
from keplar_api.models.delete_notebook_artifact_version_group200_response import DeleteNotebookArtifactVersionGroup200Response as DeleteNotebookArtifactVersionGroup200Response
from keplar_api.models.dummy_user import DummyUser as DummyUser
from keplar_api.models.email_share import EmailShare as EmailShare
from keplar_api.models.evidence import Evidence as Evidence
from keplar_api.models.feature_config import FeatureConfig as FeatureConfig
from keplar_api.models.file import File as File
from keplar_api.models.file_mime_type import FileMimeType as FileMimeType
from keplar_api.models.forbidden_error_response import ForbiddenErrorResponse as ForbiddenErrorResponse
from keplar_api.models.get_code_invite200_response import GetCodeInvite200Response as GetCodeInvite200Response
from keplar_api.models.get_code_invite_response_redirect200_response import GetCodeInviteResponseRedirect200Response as GetCodeInviteResponseRedirect200Response
from keplar_api.models.get_org_members200_response import GetOrgMembers200Response as GetOrgMembers200Response
from keplar_api.models.get_orgs200_response import GetOrgs200Response as GetOrgs200Response
from keplar_api.models.get_orgs200_response_items_inner import GetOrgs200ResponseItemsInner as GetOrgs200ResponseItemsInner
from keplar_api.models.get_orgs200_response_items_inner_default_workspace import GetOrgs200ResponseItemsInnerDefaultWorkspace as GetOrgs200ResponseItemsInnerDefaultWorkspace
from keplar_api.models.get_orgs200_response_items_inner_stats import GetOrgs200ResponseItemsInnerStats as GetOrgs200ResponseItemsInnerStats
from keplar_api.models.get_project_shares200_response import GetProjectShares200Response as GetProjectShares200Response
from keplar_api.models.get_projects200_response import GetProjects200Response as GetProjects200Response
from keplar_api.models.get_shared_artifact_version_groups200_response import GetSharedArtifactVersionGroups200Response as GetSharedArtifactVersionGroups200Response
from keplar_api.models.get_shared_invite_responses200_response import GetSharedInviteResponses200Response as GetSharedInviteResponses200Response
from keplar_api.models.get_user_workspaces200_response import GetUserWorkspaces200Response as GetUserWorkspaces200Response
from keplar_api.models.get_workspace_members200_response import GetWorkspaceMembers200Response as GetWorkspaceMembers200Response
from keplar_api.models.get_workspaces200_response import GetWorkspaces200Response as GetWorkspaces200Response
from keplar_api.models.get_workspaces200_response_items_inner import GetWorkspaces200ResponseItemsInner as GetWorkspaces200ResponseItemsInner
from keplar_api.models.hard_break_node import HardBreakNode as HardBreakNode
from keplar_api.models.heading_attrs import HeadingAttrs as HeadingAttrs
from keplar_api.models.heading_node import HeadingNode as HeadingNode
from keplar_api.models.impersonate_user200_response import ImpersonateUser200Response as ImpersonateUser200Response
from keplar_api.models.impersonate_user_request import ImpersonateUserRequest as ImpersonateUserRequest
from keplar_api.models.impersonated_user import ImpersonatedUser as ImpersonatedUser
from keplar_api.models.inbound_call_response import InboundCallResponse as InboundCallResponse
from keplar_api.models.index_project_transcripts200_response import IndexProjectTranscripts200Response as IndexProjectTranscripts200Response
from keplar_api.models.index_project_transcripts200_response_indexed import IndexProjectTranscripts200ResponseIndexed as IndexProjectTranscripts200ResponseIndexed
from keplar_api.models.inline_node import InlineNode as InlineNode
from keplar_api.models.internal_server_error_response import InternalServerErrorResponse as InternalServerErrorResponse
from keplar_api.models.invite import Invite as Invite
from keplar_api.models.invite_config import InviteConfig as InviteConfig
from keplar_api.models.invite_config_byo_panel import InviteConfigByoPanel as InviteConfigByoPanel
from keplar_api.models.invite_config_contacts import InviteConfigContacts as InviteConfigContacts
from keplar_api.models.invite_config_keplar_panel import InviteConfigKeplarPanel as InviteConfigKeplarPanel
from keplar_api.models.invite_config_public import InviteConfigPublic as InviteConfigPublic
from keplar_api.models.invite_customer_item import InviteCustomerItem as InviteCustomerItem
from keplar_api.models.invite_customers201_response import InviteCustomers201Response as InviteCustomers201Response
from keplar_api.models.invite_customers_request import InviteCustomersRequest as InviteCustomersRequest
from keplar_api.models.invite_org_result import InviteOrgResult as InviteOrgResult
from keplar_api.models.invite_response import InviteResponse as InviteResponse
from keplar_api.models.invite_response_attribute import InviteResponseAttribute as InviteResponseAttribute
from keplar_api.models.invite_response_attribute_data import InviteResponseAttributeData as InviteResponseAttributeData
from keplar_api.models.invite_response_data import InviteResponseData as InviteResponseData
from keplar_api.models.invite_response_evaluation_enum import InviteResponseEvaluationEnum as InviteResponseEvaluationEnum
from keplar_api.models.invite_response_evaluation_metadata import InviteResponseEvaluationMetadata as InviteResponseEvaluationMetadata
from keplar_api.models.invite_response_kind import InviteResponseKind as InviteResponseKind
from keplar_api.models.invite_response_metadata import InviteResponseMetadata as InviteResponseMetadata
from keplar_api.models.invite_response_share_config import InviteResponseShareConfig as InviteResponseShareConfig
from keplar_api.models.invite_response_status import InviteResponseStatus as InviteResponseStatus
from keplar_api.models.invite_response_update_event import InviteResponseUpdateEvent as InviteResponseUpdateEvent
from keplar_api.models.invite_response_with_call_summary import InviteResponseWithCallSummary as InviteResponseWithCallSummary
from keplar_api.models.invite_response_with_metadata import InviteResponseWithMetadata as InviteResponseWithMetadata
from keplar_api.models.invite_response_with_metadata_attributes_inner import InviteResponseWithMetadataAttributesInner as InviteResponseWithMetadataAttributesInner
from keplar_api.models.invite_response_with_metadata_attributes_inner_evidence import InviteResponseWithMetadataAttributesInnerEvidence as InviteResponseWithMetadataAttributesInnerEvidence
from keplar_api.models.invite_status import InviteStatus as InviteStatus
from keplar_api.models.invite_user_request import InviteUserRequest as InviteUserRequest
from keplar_api.models.invite_with_analytics import InviteWithAnalytics as InviteWithAnalytics
from keplar_api.models.invite_workspace_result import InviteWorkspaceResult as InviteWorkspaceResult
from keplar_api.models.invited_user import InvitedUser as InvitedUser
from keplar_api.models.italic_mark import ItalicMark as ItalicMark
from keplar_api.models.join_code_invite302_response import JoinCodeInvite302Response as JoinCodeInvite302Response
from keplar_api.models.join_code_invite302_response_settings import JoinCodeInvite302ResponseSettings as JoinCodeInvite302ResponseSettings
from keplar_api.models.link_mark import LinkMark as LinkMark
from keplar_api.models.link_mark_attrs import LinkMarkAttrs as LinkMarkAttrs
from keplar_api.models.list_item_node import ListItemNode as ListItemNode
from keplar_api.models.login200_response import Login200Response as Login200Response
from keplar_api.models.login200_response_any_of import Login200ResponseAnyOf as Login200ResponseAnyOf
from keplar_api.models.login400_response import Login400Response as Login400Response
from keplar_api.models.login400_response_any_of import Login400ResponseAnyOf as Login400ResponseAnyOf
from keplar_api.models.login_request import LoginRequest as LoginRequest
from keplar_api.models.mark import Mark as Mark
from keplar_api.models.mention_node import MentionNode as MentionNode
from keplar_api.models.mention_node_attrs import MentionNodeAttrs as MentionNodeAttrs
from keplar_api.models.moderator import Moderator as Moderator
from keplar_api.models.moderator_vendor import ModeratorVendor as ModeratorVendor
from keplar_api.models.moderator_visibility import ModeratorVisibility as ModeratorVisibility
from keplar_api.models.not_found_error_response import NotFoundErrorResponse as NotFoundErrorResponse
from keplar_api.models.notebook import Notebook as Notebook
from keplar_api.models.notebook_artifact_version_group import NotebookArtifactVersionGroup as NotebookArtifactVersionGroup
from keplar_api.models.notebook_artifact_version_group_metadata import NotebookArtifactVersionGroupMetadata as NotebookArtifactVersionGroupMetadata
from keplar_api.models.notebook_artifact_version_group_visibility import NotebookArtifactVersionGroupVisibility as NotebookArtifactVersionGroupVisibility
from keplar_api.models.notebook_config import NotebookConfig as NotebookConfig
from keplar_api.models.notebook_mode import NotebookMode as NotebookMode
from keplar_api.models.number_filter_schema import NumberFilterSchema as NumberFilterSchema
from keplar_api.models.open_ai_model_config import OpenAiModelConfig as OpenAiModelConfig
from keplar_api.models.option_kind import OptionKind as OptionKind
from keplar_api.models.ordered_list_attrs import OrderedListAttrs as OrderedListAttrs
from keplar_api.models.ordered_list_node import OrderedListNode as OrderedListNode
from keplar_api.models.org import Org as Org
from keplar_api.models.org_data import OrgData as OrgData
from keplar_api.models.org_default_workspace import OrgDefaultWorkspace as OrgDefaultWorkspace
from keplar_api.models.org_list_item import OrgListItem as OrgListItem
from keplar_api.models.org_member import OrgMember as OrgMember
from keplar_api.models.org_stats import OrgStats as OrgStats
from keplar_api.models.panel_qualification import PanelQualification as PanelQualification
from keplar_api.models.panel_respondent_attribute import PanelRespondentAttribute as PanelRespondentAttribute
from keplar_api.models.panel_settings import PanelSettings as PanelSettings
from keplar_api.models.paragraph_node import ParagraphNode as ParagraphNode
from keplar_api.models.participant import Participant as Participant
from keplar_api.models.participant_attribute import ParticipantAttribute as ParticipantAttribute
from keplar_api.models.participant_create import ParticipantCreate as ParticipantCreate
from keplar_api.models.participant_invite import ParticipantInvite as ParticipantInvite
from keplar_api.models.participant_invite_config import ParticipantInviteConfig as ParticipantInviteConfig
from keplar_api.models.participant_invite_data import ParticipantInviteData as ParticipantInviteData
from keplar_api.models.phone_call_start_response import PhoneCallStartResponse as PhoneCallStartResponse
from keplar_api.models.presentation_config import PresentationConfig as PresentationConfig
from keplar_api.models.presentation_config1 import PresentationConfig1 as PresentationConfig1
from keplar_api.models.project import Project as Project
from keplar_api.models.project_analysis import ProjectAnalysis as ProjectAnalysis
from keplar_api.models.project_analysis_report import ProjectAnalysisReport as ProjectAnalysisReport
from keplar_api.models.project_audience import ProjectAudience as ProjectAudience
from keplar_api.models.project_brief import ProjectBrief as ProjectBrief
from keplar_api.models.project_config import ProjectConfig as ProjectConfig
from keplar_api.models.project_conversation_config import ProjectConversationConfig as ProjectConversationConfig
from keplar_api.models.project_file import ProjectFile as ProjectFile
from keplar_api.models.project_file_category import ProjectFileCategory as ProjectFileCategory
from keplar_api.models.project_file_metadata import ProjectFileMetadata as ProjectFileMetadata
from keplar_api.models.project_file_public import ProjectFilePublic as ProjectFilePublic
from keplar_api.models.project_file_public_file import ProjectFilePublicFile as ProjectFilePublicFile
from keplar_api.models.project_kind import ProjectKind as ProjectKind
from keplar_api.models.project_share_config import ProjectShareConfig as ProjectShareConfig
from keplar_api.models.project_status import ProjectStatus as ProjectStatus
from keplar_api.models.project_summary_with_analytics import ProjectSummaryWithAnalytics as ProjectSummaryWithAnalytics
from keplar_api.models.project_with_analytics import ProjectWithAnalytics as ProjectWithAnalytics
from keplar_api.models.remaining_responses_response import RemainingResponsesResponse as RemainingResponsesResponse
from keplar_api.models.repdata_qualification import RepdataQualification as RepdataQualification
from keplar_api.models.repdata_qualification_allowed_option_ids_inner import RepdataQualificationAllowedOptionIdsInner as RepdataQualificationAllowedOptionIdsInner
from keplar_api.models.repdata_respondent_attribute import RepdataRespondentAttribute as RepdataRespondentAttribute
from keplar_api.models.repdata_survey import RepdataSurvey as RepdataSurvey
from keplar_api.models.repdata_survey_attributes import RepdataSurveyAttributes as RepdataSurveyAttributes
from keplar_api.models.repdata_survey_redirects import RepdataSurveyRedirects as RepdataSurveyRedirects
from keplar_api.models.report import Report as Report
from keplar_api.models.request_share_access200_response import RequestShareAccess200Response as RequestShareAccess200Response
from keplar_api.models.request_share_access_request import RequestShareAccessRequest as RequestShareAccessRequest
from keplar_api.models.reset_password_request import ResetPasswordRequest as ResetPasswordRequest
from keplar_api.models.response_call_completed_event import ResponseCallCompletedEvent as ResponseCallCompletedEvent
from keplar_api.models.response_call_failed_event import ResponseCallFailedEvent as ResponseCallFailedEvent
from keplar_api.models.response_consent_event import ResponseConsentEvent as ResponseConsentEvent
from keplar_api.models.response_opt_out_event import ResponseOptOutEvent as ResponseOptOutEvent
from keplar_api.models.response_processing_completed_event import ResponseProcessingCompletedEvent as ResponseProcessingCompletedEvent
from keplar_api.models.response_processing_failed_event import ResponseProcessingFailedEvent as ResponseProcessingFailedEvent
from keplar_api.models.response_redirect_event import ResponseRedirectEvent as ResponseRedirectEvent
from keplar_api.models.response_start_call_event import ResponseStartCallEvent as ResponseStartCallEvent
from keplar_api.models.response_submit_email_event import ResponseSubmitEmailEvent as ResponseSubmitEmailEvent
from keplar_api.models.response_submit_screener_event import ResponseSubmitScreenerEvent as ResponseSubmitScreenerEvent
from keplar_api.models.save_search_request import SaveSearchRequest as SaveSearchRequest
from keplar_api.models.save_search_request_tabs_inner import SaveSearchRequestTabsInner as SaveSearchRequestTabsInner
from keplar_api.models.screener_question import ScreenerQuestion as ScreenerQuestion
from keplar_api.models.screener_question_choose_multiple import ScreenerQuestionChooseMultiple as ScreenerQuestionChooseMultiple
from keplar_api.models.screener_question_choose_multiple_options_value import ScreenerQuestionChooseMultipleOptionsValue as ScreenerQuestionChooseMultipleOptionsValue
from keplar_api.models.screener_question_choose_multiple_public import ScreenerQuestionChooseMultiplePublic as ScreenerQuestionChooseMultiplePublic
from keplar_api.models.screener_question_choose_one import ScreenerQuestionChooseOne as ScreenerQuestionChooseOne
from keplar_api.models.screener_question_choose_one_public import ScreenerQuestionChooseOnePublic as ScreenerQuestionChooseOnePublic
from keplar_api.models.screener_question_option import ScreenerQuestionOption as ScreenerQuestionOption
from keplar_api.models.screener_question_public import ScreenerQuestionPublic as ScreenerQuestionPublic
from keplar_api.models.screener_question_response import ScreenerQuestionResponse as ScreenerQuestionResponse
from keplar_api.models.search_project_transcripts_response import SearchProjectTranscriptsResponse as SearchProjectTranscriptsResponse
from keplar_api.models.search_shared_response_messages200_response_inner import SearchSharedResponseMessages200ResponseInner as SearchSharedResponseMessages200ResponseInner
from keplar_api.models.search_shared_response_messages_request import SearchSharedResponseMessagesRequest as SearchSharedResponseMessagesRequest
from keplar_api.models.search_shared_response_messages_request_invite_response_messages_inner import SearchSharedResponseMessagesRequestInviteResponseMessagesInner as SearchSharedResponseMessagesRequestInviteResponseMessagesInner
from keplar_api.models.search_users200_response import SearchUsers200Response as SearchUsers200Response
from keplar_api.models.search_users_request import SearchUsersRequest as SearchUsersRequest
from keplar_api.models.select_filter_schema import SelectFilterSchema as SelectFilterSchema
from keplar_api.models.share_entity import ShareEntity as ShareEntity
from keplar_api.models.share_entity_config import ShareEntityConfig as ShareEntityConfig
from keplar_api.models.share_entity_created_by_kind import ShareEntityCreatedByKind as ShareEntityCreatedByKind
from keplar_api.models.share_entity_kind import ShareEntityKind as ShareEntityKind
from keplar_api.models.signup_request import SignupRequest as SignupRequest
from keplar_api.models.skipped_customer import SkippedCustomer as SkippedCustomer
from keplar_api.models.start_phone_call_for_code_invite_response_request import StartPhoneCallForCodeInviteResponseRequest as StartPhoneCallForCodeInviteResponseRequest
from keplar_api.models.supported_language import SupportedLanguage as SupportedLanguage
from keplar_api.models.text_node import TextNode as TextNode
from keplar_api.models.thematic_analysis_artifact_create_data import ThematicAnalysisArtifactCreateData as ThematicAnalysisArtifactCreateData
from keplar_api.models.thematic_analysis_artifact_create_data_themes_inner import ThematicAnalysisArtifactCreateDataThemesInner as ThematicAnalysisArtifactCreateDataThemesInner
from keplar_api.models.thematic_analysis_artifact_create_data_themes_inner_codes_inner import ThematicAnalysisArtifactCreateDataThemesInnerCodesInner as ThematicAnalysisArtifactCreateDataThemesInnerCodesInner
from keplar_api.models.thematic_analysis_response_code import ThematicAnalysisResponseCode as ThematicAnalysisResponseCode
from keplar_api.models.thematic_analysis_response_code_codes_inner import ThematicAnalysisResponseCodeCodesInner as ThematicAnalysisResponseCodeCodesInner
from keplar_api.models.thematic_analysis_response_code_codes_inner_evidence import ThematicAnalysisResponseCodeCodesInnerEvidence as ThematicAnalysisResponseCodeCodesInnerEvidence
from keplar_api.models.thread import Thread as Thread
from keplar_api.models.thread_create_project_status import ThreadCreateProjectStatus as ThreadCreateProjectStatus
from keplar_api.models.thread_file import ThreadFile as ThreadFile
from keplar_api.models.thread_kind import ThreadKind as ThreadKind
from keplar_api.models.thread_metadata import ThreadMetadata as ThreadMetadata
from keplar_api.models.token_kind import TokenKind as TokenKind
from keplar_api.models.transcript import Transcript as Transcript
from keplar_api.models.transcript_attributes_inner import TranscriptAttributesInner as TranscriptAttributesInner
from keplar_api.models.transcript_message import TranscriptMessage as TranscriptMessage
from keplar_api.models.transcript_messages_inner import TranscriptMessagesInner as TranscriptMessagesInner
from keplar_api.models.transcript_quality import TranscriptQuality as TranscriptQuality
from keplar_api.models.transcript_response_attribute import TranscriptResponseAttribute as TranscriptResponseAttribute
from keplar_api.models.unauthorized_error_response import UnauthorizedErrorResponse as UnauthorizedErrorResponse
from keplar_api.models.update_artifact_request import UpdateArtifactRequest as UpdateArtifactRequest
from keplar_api.models.update_call_for_code_invite_response_request import UpdateCallForCodeInviteResponseRequest as UpdateCallForCodeInviteResponseRequest
from keplar_api.models.update_call_for_code_invite_response_request_call import UpdateCallForCodeInviteResponseRequestCall as UpdateCallForCodeInviteResponseRequestCall
from keplar_api.models.update_code_invite_response404_response import UpdateCodeInviteResponse404Response as UpdateCodeInviteResponse404Response
from keplar_api.models.update_notebook_request import UpdateNotebookRequest as UpdateNotebookRequest
from keplar_api.models.update_notebook_request_config import UpdateNotebookRequestConfig as UpdateNotebookRequestConfig
from keplar_api.models.update_notebook_sources_request import UpdateNotebookSourcesRequest as UpdateNotebookSourcesRequest
from keplar_api.models.update_org2_fa_request import UpdateOrg2FARequest as UpdateOrg2FARequest
from keplar_api.models.update_org_default_workspace_request import UpdateOrgDefaultWorkspaceRequest as UpdateOrgDefaultWorkspaceRequest
from keplar_api.models.update_search_request import UpdateSearchRequest as UpdateSearchRequest
from keplar_api.models.update_share_entity_request import UpdateShareEntityRequest as UpdateShareEntityRequest
from keplar_api.models.update_user_default_workspace200_response import UpdateUserDefaultWorkspace200Response as UpdateUserDefaultWorkspace200Response
from keplar_api.models.update_user_default_workspace_request import UpdateUserDefaultWorkspaceRequest as UpdateUserDefaultWorkspaceRequest
from keplar_api.models.update_workspace_member_request import UpdateWorkspaceMemberRequest as UpdateWorkspaceMemberRequest
from keplar_api.models.upload_call_video_response import UploadCallVideoResponse as UploadCallVideoResponse
from keplar_api.models.user import User as User
from keplar_api.models.user_account_status import UserAccountStatus as UserAccountStatus
from keplar_api.models.user_admin_level import UserAdminLevel as UserAdminLevel
from keplar_api.models.user_data import UserData as UserData
from keplar_api.models.user_default_workspace import UserDefaultWorkspace as UserDefaultWorkspace
from keplar_api.models.user_org import UserOrg as UserOrg
from keplar_api.models.user_project import UserProject as UserProject
from keplar_api.models.user_provider import UserProvider as UserProvider
from keplar_api.models.user_search_result import UserSearchResult as UserSearchResult
from keplar_api.models.user_with_config import UserWithConfig as UserWithConfig
from keplar_api.models.user_workspace_item import UserWorkspaceItem as UserWorkspaceItem
from keplar_api.models.vapi_assistant_config import VapiAssistantConfig as VapiAssistantConfig
from keplar_api.models.vapi_voice_id import VapiVoiceId as VapiVoiceId
from keplar_api.models.vapi_voice_vapi_provider import VapiVoiceVapiProvider as VapiVoiceVapiProvider
from keplar_api.models.verify_email_access_for_share200_response import VerifyEmailAccessForShare200Response as VerifyEmailAccessForShare200Response
from keplar_api.models.verify_email_access_for_share_request import VerifyEmailAccessForShareRequest as VerifyEmailAccessForShareRequest
from keplar_api.models.verify_email_request import VerifyEmailRequest as VerifyEmailRequest
from keplar_api.models.video_recording_settings import VideoRecordingSettings as VideoRecordingSettings
from keplar_api.models.video_recording_status import VideoRecordingStatus as VideoRecordingStatus
from keplar_api.models.workspace import Workspace as Workspace
from keplar_api.models.workspace_list_item import WorkspaceListItem as WorkspaceListItem
from keplar_api.models.workspace_member import WorkspaceMember as WorkspaceMember
from keplar_api.models.workspace_member_item import WorkspaceMemberItem as WorkspaceMemberItem
from keplar_api.models.workspace_member_response import WorkspaceMemberResponse as WorkspaceMemberResponse
from keplar_api.models.workspace_member_role import WorkspaceMemberRole as WorkspaceMemberRole
from keplar_api.models.workspace_member_user import WorkspaceMemberUser as WorkspaceMemberUser




# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from keplar_api.models.token_kind import TokenKind
from keplar_api.models.user_account_status import UserAccountStatus
from keplar_api.models.user_data import UserData
from keplar_api.models.user_provider import UserProvider
from typing import Optional, Set
from typing_extensions import Self

class User(BaseModel):
    """
    User
    """ # noqa: E501
    id: StrictStr
    seq: Union[StrictFloat, StrictInt]
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    provider: UserProvider
    user_id: StrictStr = Field(alias="userId")
    email: StrictStr
    name: StrictStr
    account_status: UserAccountStatus = Field(alias="accountStatus")
    location: Optional[StrictStr] = None
    profile_image_url: Optional[StrictStr] = Field(default=None, alias="profileImageUrl")
    data: Optional[UserData] = None
    password_hash: Optional[StrictStr] = Field(default=None, alias="passwordHash")
    email_verified_at: Optional[datetime] = Field(default=None, alias="emailVerifiedAt")
    token: Optional[StrictStr] = None
    token_kind: Optional[TokenKind] = Field(default=None, alias="tokenKind")
    token_expiry: Optional[datetime] = Field(default=None, alias="tokenExpiry")
    org_id: Optional[StrictStr] = Field(default=None, alias="orgId")
    default_workspace_id: StrictStr = Field(alias="defaultWorkspaceId")
    org: Optional[Org] = None
    default_workspace: Optional[Workspace] = Field(default=None, alias="defaultWorkspace")
    workspace_members: Optional[List[WorkspaceMember]] = Field(default=None, alias="workspaceMembers")
    projects: Optional[List[Project]] = None
    invites: Optional[List[Invite]] = None
    chat_sessions: Optional[List[ChatSession]] = Field(default=None, alias="chatSessions")
    moderators: Optional[List[Moderator]] = None
    uploaded_files: Optional[List[File]] = Field(default=None, alias="uploadedFiles")
    threads: Optional[List[Thread]] = None
    attribute_kind_group: Optional[List[AttributeKindGroup]] = Field(default=None, alias="AttributeKindGroup")
    artifact: Optional[List[Artifact]] = Field(default=None, alias="Artifact")
    notebooks: Optional[List[Notebook]] = None
    __properties: ClassVar[List[str]] = ["id", "seq", "createdAt", "updatedAt", "provider", "userId", "email", "name", "accountStatus", "location", "profileImageUrl", "data", "passwordHash", "emailVerifiedAt", "token", "tokenKind", "tokenExpiry", "orgId", "defaultWorkspaceId", "org", "defaultWorkspace", "workspaceMembers", "projects", "invites", "chatSessions", "moderators", "uploadedFiles", "threads", "AttributeKindGroup", "Artifact", "notebooks"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of User from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of data
        if self.data:
            _dict['data'] = self.data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of org
        if self.org:
            _dict['org'] = self.org.to_dict()
        # override the default output from pydantic by calling `to_dict()` of default_workspace
        if self.default_workspace:
            _dict['defaultWorkspace'] = self.default_workspace.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in workspace_members (list)
        _items = []
        if self.workspace_members:
            for _item_workspace_members in self.workspace_members:
                if _item_workspace_members:
                    _items.append(_item_workspace_members.to_dict())
            _dict['workspaceMembers'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in projects (list)
        _items = []
        if self.projects:
            for _item_projects in self.projects:
                if _item_projects:
                    _items.append(_item_projects.to_dict())
            _dict['projects'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in invites (list)
        _items = []
        if self.invites:
            for _item_invites in self.invites:
                if _item_invites:
                    _items.append(_item_invites.to_dict())
            _dict['invites'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in chat_sessions (list)
        _items = []
        if self.chat_sessions:
            for _item_chat_sessions in self.chat_sessions:
                if _item_chat_sessions:
                    _items.append(_item_chat_sessions.to_dict())
            _dict['chatSessions'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in moderators (list)
        _items = []
        if self.moderators:
            for _item_moderators in self.moderators:
                if _item_moderators:
                    _items.append(_item_moderators.to_dict())
            _dict['moderators'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in uploaded_files (list)
        _items = []
        if self.uploaded_files:
            for _item_uploaded_files in self.uploaded_files:
                if _item_uploaded_files:
                    _items.append(_item_uploaded_files.to_dict())
            _dict['uploadedFiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in threads (list)
        _items = []
        if self.threads:
            for _item_threads in self.threads:
                if _item_threads:
                    _items.append(_item_threads.to_dict())
            _dict['threads'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in attribute_kind_group (list)
        _items = []
        if self.attribute_kind_group:
            for _item_attribute_kind_group in self.attribute_kind_group:
                if _item_attribute_kind_group:
                    _items.append(_item_attribute_kind_group.to_dict())
            _dict['AttributeKindGroup'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in artifact (list)
        _items = []
        if self.artifact:
            for _item_artifact in self.artifact:
                if _item_artifact:
                    _items.append(_item_artifact.to_dict())
            _dict['Artifact'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in notebooks (list)
        _items = []
        if self.notebooks:
            for _item_notebooks in self.notebooks:
                if _item_notebooks:
                    _items.append(_item_notebooks.to_dict())
            _dict['notebooks'] = _items
        # set to None if location (nullable) is None
        # and model_fields_set contains the field
        if self.location is None and "location" in self.model_fields_set:
            _dict['location'] = None

        # set to None if profile_image_url (nullable) is None
        # and model_fields_set contains the field
        if self.profile_image_url is None and "profile_image_url" in self.model_fields_set:
            _dict['profileImageUrl'] = None

        # set to None if data (nullable) is None
        # and model_fields_set contains the field
        if self.data is None and "data" in self.model_fields_set:
            _dict['data'] = None

        # set to None if password_hash (nullable) is None
        # and model_fields_set contains the field
        if self.password_hash is None and "password_hash" in self.model_fields_set:
            _dict['passwordHash'] = None

        # set to None if email_verified_at (nullable) is None
        # and model_fields_set contains the field
        if self.email_verified_at is None and "email_verified_at" in self.model_fields_set:
            _dict['emailVerifiedAt'] = None

        # set to None if token (nullable) is None
        # and model_fields_set contains the field
        if self.token is None and "token" in self.model_fields_set:
            _dict['token'] = None

        # set to None if token_kind (nullable) is None
        # and model_fields_set contains the field
        if self.token_kind is None and "token_kind" in self.model_fields_set:
            _dict['tokenKind'] = None

        # set to None if token_expiry (nullable) is None
        # and model_fields_set contains the field
        if self.token_expiry is None and "token_expiry" in self.model_fields_set:
            _dict['tokenExpiry'] = None

        # set to None if org_id (nullable) is None
        # and model_fields_set contains the field
        if self.org_id is None and "org_id" in self.model_fields_set:
            _dict['orgId'] = None

        # set to None if org (nullable) is None
        # and model_fields_set contains the field
        if self.org is None and "org" in self.model_fields_set:
            _dict['org'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of User from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "seq": obj.get("seq"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "provider": obj.get("provider"),
            "userId": obj.get("userId"),
            "email": obj.get("email"),
            "name": obj.get("name"),
            "accountStatus": obj.get("accountStatus"),
            "location": obj.get("location"),
            "profileImageUrl": obj.get("profileImageUrl"),
            "data": UserData.from_dict(obj["data"]) if obj.get("data") is not None else None,
            "passwordHash": obj.get("passwordHash"),
            "emailVerifiedAt": obj.get("emailVerifiedAt"),
            "token": obj.get("token"),
            "tokenKind": obj.get("tokenKind"),
            "tokenExpiry": obj.get("tokenExpiry"),
            "orgId": obj.get("orgId"),
            "defaultWorkspaceId": obj.get("defaultWorkspaceId"),
            "org": Org.from_dict(obj["org"]) if obj.get("org") is not None else None,
            "defaultWorkspace": Workspace.from_dict(obj["defaultWorkspace"]) if obj.get("defaultWorkspace") is not None else None,
            "workspaceMembers": [WorkspaceMember.from_dict(_item) for _item in obj["workspaceMembers"]] if obj.get("workspaceMembers") is not None else None,
            "projects": [Project.from_dict(_item) for _item in obj["projects"]] if obj.get("projects") is not None else None,
            "invites": [Invite.from_dict(_item) for _item in obj["invites"]] if obj.get("invites") is not None else None,
            "chatSessions": [ChatSession.from_dict(_item) for _item in obj["chatSessions"]] if obj.get("chatSessions") is not None else None,
            "moderators": [Moderator.from_dict(_item) for _item in obj["moderators"]] if obj.get("moderators") is not None else None,
            "uploadedFiles": [File.from_dict(_item) for _item in obj["uploadedFiles"]] if obj.get("uploadedFiles") is not None else None,
            "threads": [Thread.from_dict(_item) for _item in obj["threads"]] if obj.get("threads") is not None else None,
            "AttributeKindGroup": [AttributeKindGroup.from_dict(_item) for _item in obj["AttributeKindGroup"]] if obj.get("AttributeKindGroup") is not None else None,
            "Artifact": [Artifact.from_dict(_item) for _item in obj["Artifact"]] if obj.get("Artifact") is not None else None,
            "notebooks": [Notebook.from_dict(_item) for _item in obj["notebooks"]] if obj.get("notebooks") is not None else None
        })
        return _obj

from keplar_api.models.artifact import Artifact
from keplar_api.models.attribute_kind_group import AttributeKindGroup
from keplar_api.models.chat_session import ChatSession
from keplar_api.models.file import File
from keplar_api.models.invite import Invite
from keplar_api.models.moderator import Moderator
from keplar_api.models.notebook import Notebook
from keplar_api.models.org import Org
from keplar_api.models.project import Project
from keplar_api.models.thread import Thread
from keplar_api.models.workspace import Workspace
from keplar_api.models.workspace_member import WorkspaceMember
# TODO: Rewrite to not use raise_errors
User.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.artifact_data_thematic_analysis import ArtifactDataThematicAnalysis

class TestArtifactDataThematicAnalysis(unittest.TestCase):
    """ArtifactDataThematicAnalysis unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ArtifactDataThematicAnalysis:
        """Test ArtifactDataThematicAnalysis
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ArtifactDataThematicAnalysis`
        """
        model = ArtifactDataThematicAnalysis()
        if include_optional:
            return ArtifactDataThematicAnalysis(
                kind = 'thematic_analysis',
                data = keplar_api.models.artifact_data_thematic_analysis_data.ArtifactDataThematicAnalysis_data(
                    query = '', 
                    summary = '', 
                    themes = [
                        keplar_api.models.artifact_data_thematic_analysis_data_themes_inner.ArtifactDataThematicAnalysis_data_themes_inner(
                            label = '', 
                            description = '', )
                        ], )
            )
        else:
            return ArtifactDataThematicAnalysis(
                kind = 'thematic_analysis',
                data = keplar_api.models.artifact_data_thematic_analysis_data.ArtifactDataThematicAnalysis_data(
                    query = '', 
                    summary = '', 
                    themes = [
                        keplar_api.models.artifact_data_thematic_analysis_data_themes_inner.ArtifactDataThematicAnalysis_data_themes_inner(
                            label = '', 
                            description = '', )
                        ], ),
        )
        """

    def testArtifactDataThematicAnalysis(self):
        """Test ArtifactDataThematicAnalysis"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.phone_call_start_response import PhoneCallStartResponse

class TestPhoneCallStartResponse(unittest.TestCase):
    """PhoneCallStartResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PhoneCallStartResponse:
        """Test PhoneCallStartResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PhoneCallStartResponse`
        """
        model = PhoneCallStartResponse()
        if include_optional:
            return PhoneCallStartResponse(
                id = '',
                status = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return PhoneCallStartResponse(
                id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testPhoneCallStartResponse(self):
        """Test PhoneCallStartResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.call_metadata import CallMetadata

class TestCallMetadata(unittest.TestCase):
    """CallMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CallMetadata:
        """Test CallMetadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CallMetadata`
        """
        model = CallMetadata()
        if include_optional:
            return CallMetadata(
                recording_url = '',
                transcript = '',
                transcript_quality = 'HIGH',
                transcript_markdown = '',
                transcript_insight = '',
                analysis = keplar_api.models.call_analysis.CallAnalysis(
                    summary = '', 
                    success_evaluation = '', ),
                gcs_url = '',
                gcs_path = '',
                gcs_uploaded_at = '',
                gcs_last_synced_at = '',
                video_recording_url = '',
                video_gcs_url = '',
                video_gcs_path = '',
                video_uploaded_at = '',
                video_mime_type = '',
                video_duration_seconds = 1.337,
                video_size_bytes = 1.337,
                video_recording_status = 'recording',
                video_recording_error = ''
            )
        else:
            return CallMetadata(
        )
        """

    def testCallMetadata(self):
        """Test CallMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.search_project_transcripts_response import SearchProjectTranscriptsResponse

class TestSearchProjectTranscriptsResponse(unittest.TestCase):
    """SearchProjectTranscriptsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchProjectTranscriptsResponse:
        """Test SearchProjectTranscriptsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchProjectTranscriptsResponse`
        """
        model = SearchProjectTranscriptsResponse()
        if include_optional:
            return SearchProjectTranscriptsResponse(
                transcripts = [
                    keplar_api.models.transcript.Transcript(
                        id = '', 
                        response_id = '', 
                        messages = [
                            keplar_api.models.transcript_messages_inner.Transcript_messages_inner(
                                call_id = '', 
                                index = 1.337, 
                                role = '', 
                                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                message = '', )
                            ], 
                        attributes = [
                            keplar_api.models.transcript_attributes_inner.Transcript_attributes_inner(
                                label = '', 
                                value = '', )
                            ], )
                    ],
                total = 1.337,
                page = 1.337,
                limit = 1.337
            )
        else:
            return SearchProjectTranscriptsResponse(
                transcripts = [
                    keplar_api.models.transcript.Transcript(
                        id = '', 
                        response_id = '', 
                        messages = [
                            keplar_api.models.transcript_messages_inner.Transcript_messages_inner(
                                call_id = '', 
                                index = 1.337, 
                                role = '', 
                                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                message = '', )
                            ], 
                        attributes = [
                            keplar_api.models.transcript_attributes_inner.Transcript_attributes_inner(
                                label = '', 
                                value = '', )
                            ], )
                    ],
                total = 1.337,
                page = 1.337,
                limit = 1.337,
        )
        """

    def testSearchProjectTranscriptsResponse(self):
        """Test SearchProjectTranscriptsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.get_orgs200_response import GetOrgs200Response

class TestGetOrgs200Response(unittest.TestCase):
    """GetOrgs200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetOrgs200Response:
        """Test GetOrgs200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetOrgs200Response`
        """
        model = GetOrgs200Response()
        if include_optional:
            return GetOrgs200Response(
                items = [
                    keplar_api.models.get_orgs_200_response_items_inner.getOrgs_200_response_items_inner(
                        id = '', 
                        name = '', 
                        domain = '', 
                        is2_fa_enabled = True, 
                        default_workspace_id = '', 
                        default_workspace = keplar_api.models.get_orgs_200_response_items_inner_default_workspace.getOrgs_200_response_items_inner_defaultWorkspace(
                            id = '', 
                            name = '', ), 
                        stats = keplar_api.models.get_orgs_200_response_items_inner_stats.getOrgs_200_response_items_inner_stats(
                            total_projects = 1.337, 
                            total_responses_completed = 1.337, 
                            total_responses = 1.337, 
                            total_members = 1.337, 
                            last_activity_at = '', ), 
                        created_at = '', 
                        updated_at = '', )
                    ],
                total = 1.337,
                page = 1.337,
                limit = 1.337
            )
        else:
            return GetOrgs200Response(
                items = [
                    keplar_api.models.get_orgs_200_response_items_inner.getOrgs_200_response_items_inner(
                        id = '', 
                        name = '', 
                        domain = '', 
                        is2_fa_enabled = True, 
                        default_workspace_id = '', 
                        default_workspace = keplar_api.models.get_orgs_200_response_items_inner_default_workspace.getOrgs_200_response_items_inner_defaultWorkspace(
                            id = '', 
                            name = '', ), 
                        stats = keplar_api.models.get_orgs_200_response_items_inner_stats.getOrgs_200_response_items_inner_stats(
                            total_projects = 1.337, 
                            total_responses_completed = 1.337, 
                            total_responses = 1.337, 
                            total_members = 1.337, 
                            last_activity_at = '', ), 
                        created_at = '', 
                        updated_at = '', )
                    ],
                total = 1.337,
                page = 1.337,
                limit = 1.337,
        )
        """

    def testGetOrgs200Response(self):
        """Test GetOrgs200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.code_invite_config import CodeInviteConfig

class TestCodeInviteConfig(unittest.TestCase):
    """CodeInviteConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CodeInviteConfig:
        """Test CodeInviteConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CodeInviteConfig`
        """
        model = CodeInviteConfig()
        if include_optional:
            return CodeInviteConfig(
                kind = 'BYO_PANEL',
                collect_email = True,
                require_email = True,
                panel_settings = keplar_api.models.panel_settings.PanelSettings(
                    respondent_attributes = [
                        keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                            qualifications = [
                                keplar_api.models.panel_qualification.PanelQualification(
                                    allowed_option_ids = [
                                        null
                                        ], 
                                    question_id = 1.337, )
                                ], 
                            quota = 1.337, 
                            quota_name = '', )
                        ], 
                    country_code = '', 
                    language_code = '', 
                    length_of_interview = 1.337, 
                    incidence_rate = 1.337, 
                    compensation = 1.337, ),
                title = '',
                description = '',
                max_responses = 1.337,
                max_responses_per_participant = 1.337,
                video_recording = keplar_api.models.video_recording_settings.VideoRecordingSettings(
                    enabled = True, 
                    include_audio = True, ),
                is_test = True,
                show_call_metadata = True,
                allowed_origins = [
                    ''
                    ],
                byo_panel_config = keplar_api.models.byo_panel_repdata_config.ByoPanelRepdataConfig(
                    kind = 'REPDATA', 
                    selected_qualifications = [
                        keplar_api.models.repdata_qualification.RepdataQualification(
                            question_id = 1.337, 
                            allowed_option_ids = [
                                null
                                ], )
                        ], )
            )
        else:
            return CodeInviteConfig(
                kind = 'BYO_PANEL',
                panel_settings = keplar_api.models.panel_settings.PanelSettings(
                    respondent_attributes = [
                        keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                            qualifications = [
                                keplar_api.models.panel_qualification.PanelQualification(
                                    allowed_option_ids = [
                                        null
                                        ], 
                                    question_id = 1.337, )
                                ], 
                            quota = 1.337, 
                            quota_name = '', )
                        ], 
                    country_code = '', 
                    language_code = '', 
                    length_of_interview = 1.337, 
                    incidence_rate = 1.337, 
                    compensation = 1.337, ),
                title = '',
                byo_panel_config = keplar_api.models.byo_panel_repdata_config.ByoPanelRepdataConfig(
                    kind = 'REPDATA', 
                    selected_qualifications = [
                        keplar_api.models.repdata_qualification.RepdataQualification(
                            question_id = 1.337, 
                            allowed_option_ids = [
                                null
                                ], )
                        ], ),
        )
        """

    def testCodeInviteConfig(self):
        """Test CodeInviteConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.vapi_assistant_config import VapiAssistantConfig

class TestVapiAssistantConfig(unittest.TestCase):
    """VapiAssistantConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VapiAssistantConfig:
        """Test VapiAssistantConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VapiAssistantConfig`
        """
        model = VapiAssistantConfig()
        if include_optional:
            return VapiAssistantConfig(
                system_prompt = '',
                model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                    provider = 'openai', 
                    model = 'gpt-4.1', ),
                first_message = '',
                end_call_message = '',
                max_duration_seconds = 1.337,
                voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                    provider = 'vapi', 
                    voice_id = 'Elliot', ),
                tools = [
                    keplar_api.models.chat_completion_tool.ChatCompletionTool(
                        type = 'function', 
                        function = keplar_api.models.chat_completion_tool_function.ChatCompletionTool_function(
                            name = '', 
                            description = '', 
                            parameters = {
                                'key' : null
                                }, ), )
                    ],
                language = 'en'
            )
        else:
            return VapiAssistantConfig(
                system_prompt = '',
                model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                    provider = 'openai', 
                    model = 'gpt-4.1', ),
                first_message = '',
                end_call_message = '',
                max_duration_seconds = 1.337,
                voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                    provider = 'vapi', 
                    voice_id = 'Elliot', ),
        )
        """

    def testVapiAssistantConfig(self):
        """Test VapiAssistantConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.thematic_analysis_response_code_codes_inner import ThematicAnalysisResponseCodeCodesInner

class TestThematicAnalysisResponseCodeCodesInner(unittest.TestCase):
    """ThematicAnalysisResponseCodeCodesInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ThematicAnalysisResponseCodeCodesInner:
        """Test ThematicAnalysisResponseCodeCodesInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ThematicAnalysisResponseCodeCodesInner`
        """
        model = ThematicAnalysisResponseCodeCodesInner()
        if include_optional:
            return ThematicAnalysisResponseCodeCodesInner(
                theme = '',
                code = '',
                evidence = keplar_api.models.thematic_analysis_response_code_codes_inner_evidence.ThematicAnalysisResponseCode_codes_inner_evidence(
                    message_index = 56, 
                    excerpt = '', 
                    confidence = 56, )
            )
        else:
            return ThematicAnalysisResponseCodeCodesInner(
                theme = '',
                code = '',
                evidence = keplar_api.models.thematic_analysis_response_code_codes_inner_evidence.ThematicAnalysisResponseCode_codes_inner_evidence(
                    message_index = 56, 
                    excerpt = '', 
                    confidence = 56, ),
        )
        """

    def testThematicAnalysisResponseCodeCodesInner(self):
        """Test ThematicAnalysisResponseCodeCodesInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.api_threads_thread_id_project_brief_document_versions_version_put200_response import ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response

class TestApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response(unittest.TestCase):
    """ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response:
        """Test ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response`
        """
        model = ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response()
        if include_optional:
            return ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response(
                version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                    doc = keplar_api.models.brief_document.BriefDocument(
                        type = 'doc', 
                        content = [
                            keplar_api.models.content_node.ContentNode()
                            ], ), 
                    version = 1.337, 
                    created_at = '', 
                    updated_at = '', )
            )
        else:
            return ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response(
                version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                    doc = keplar_api.models.brief_document.BriefDocument(
                        type = 'doc', 
                        content = [
                            keplar_api.models.content_node.ContentNode()
                            ], ), 
                    version = 1.337, 
                    created_at = '', 
                    updated_at = '', ),
        )
        """

    def testApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response(self):
        """Test ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.create_notebook_artifact_request import CreateNotebookArtifactRequest

class TestCreateNotebookArtifactRequest(unittest.TestCase):
    """CreateNotebookArtifactRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateNotebookArtifactRequest:
        """Test CreateNotebookArtifactRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateNotebookArtifactRequest`
        """
        model = CreateNotebookArtifactRequest()
        if include_optional:
            return CreateNotebookArtifactRequest(
                kind = 'thematic_analysis',
                metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                    status = 'draft', 
                    status_message = '', 
                    progress = 1.337, 
                    description = '', ),
                data = keplar_api.models.artifact_data_not_null.ArtifactDataNotNull()
            )
        else:
            return CreateNotebookArtifactRequest(
        )
        """

    def testCreateNotebookArtifactRequest(self):
        """Test CreateNotebookArtifactRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.vapi_voice_id import VapiVoiceId

class TestVapiVoiceId(unittest.TestCase):
    """VapiVoiceId unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testVapiVoiceId(self):
        """Test VapiVoiceId"""
        # inst = VapiVoiceId()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.create_project_preview_invite_request import CreateProjectPreviewInviteRequest

class TestCreateProjectPreviewInviteRequest(unittest.TestCase):
    """CreateProjectPreviewInviteRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateProjectPreviewInviteRequest:
        """Test CreateProjectPreviewInviteRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateProjectPreviewInviteRequest`
        """
        model = CreateProjectPreviewInviteRequest()
        if include_optional:
            return CreateProjectPreviewInviteRequest(
                title = '',
                description = '',
                target_email = ''
            )
        else:
            return CreateProjectPreviewInviteRequest(
        )
        """

    def testCreateProjectPreviewInviteRequest(self):
        """Test CreateProjectPreviewInviteRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.thread_kind import ThreadKind
from keplar_api.models.thread_metadata import ThreadMetadata
from typing import Optional, Set
from typing_extensions import Self

class Thread(BaseModel):
    """
    Thread
    """ # noqa: E501
    id: StrictStr
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    name: StrictStr
    kind: Optional[ThreadKind] = None
    description: Optional[StrictStr] = None
    metadata: Optional[ThreadMetadata] = None
    created_by_id: StrictStr = Field(alias="createdById")
    workspace_id: StrictStr = Field(alias="workspaceId")
    project_id: Optional[StrictStr] = Field(default=None, alias="projectId")
    notebook_id: Optional[StrictStr] = Field(default=None, alias="notebookId")
    created_by: Optional[User] = Field(default=None, alias="createdBy")
    workspace: Optional[Workspace] = None
    project: Optional[Project] = None
    notebook: Optional[Notebook] = None
    thread_files: Optional[List[ThreadFile]] = Field(default=None, alias="threadFiles")
    __properties: ClassVar[List[str]] = ["id", "createdAt", "updatedAt", "name", "kind", "description", "metadata", "createdById", "workspaceId", "projectId", "notebookId", "createdBy", "workspace", "project", "notebook", "threadFiles"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Thread from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict['metadata'] = self.metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of created_by
        if self.created_by:
            _dict['createdBy'] = self.created_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of workspace
        if self.workspace:
            _dict['workspace'] = self.workspace.to_dict()
        # override the default output from pydantic by calling `to_dict()` of project
        if self.project:
            _dict['project'] = self.project.to_dict()
        # override the default output from pydantic by calling `to_dict()` of notebook
        if self.notebook:
            _dict['notebook'] = self.notebook.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in thread_files (list)
        _items = []
        if self.thread_files:
            for _item_thread_files in self.thread_files:
                if _item_thread_files:
                    _items.append(_item_thread_files.to_dict())
            _dict['threadFiles'] = _items
        # set to None if kind (nullable) is None
        # and model_fields_set contains the field
        if self.kind is None and "kind" in self.model_fields_set:
            _dict['kind'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        # set to None if project_id (nullable) is None
        # and model_fields_set contains the field
        if self.project_id is None and "project_id" in self.model_fields_set:
            _dict['projectId'] = None

        # set to None if notebook_id (nullable) is None
        # and model_fields_set contains the field
        if self.notebook_id is None and "notebook_id" in self.model_fields_set:
            _dict['notebookId'] = None

        # set to None if project (nullable) is None
        # and model_fields_set contains the field
        if self.project is None and "project" in self.model_fields_set:
            _dict['project'] = None

        # set to None if notebook (nullable) is None
        # and model_fields_set contains the field
        if self.notebook is None and "notebook" in self.model_fields_set:
            _dict['notebook'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Thread from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "name": obj.get("name"),
            "kind": obj.get("kind"),
            "description": obj.get("description"),
            "metadata": ThreadMetadata.from_dict(obj["metadata"]) if obj.get("metadata") is not None else None,
            "createdById": obj.get("createdById"),
            "workspaceId": obj.get("workspaceId"),
            "projectId": obj.get("projectId"),
            "notebookId": obj.get("notebookId"),
            "createdBy": User.from_dict(obj["createdBy"]) if obj.get("createdBy") is not None else None,
            "workspace": Workspace.from_dict(obj["workspace"]) if obj.get("workspace") is not None else None,
            "project": Project.from_dict(obj["project"]) if obj.get("project") is not None else None,
            "notebook": Notebook.from_dict(obj["notebook"]) if obj.get("notebook") is not None else None,
            "threadFiles": [ThreadFile.from_dict(_item) for _item in obj["threadFiles"]] if obj.get("threadFiles") is not None else None
        })
        return _obj

from keplar_api.models.notebook import Notebook
from keplar_api.models.project import Project
from keplar_api.models.thread_file import ThreadFile
from keplar_api.models.user import User
from keplar_api.models.workspace import Workspace
# TODO: Rewrite to not use raise_errors
Thread.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.invite_config_byo_panel import InviteConfigByoPanel

class TestInviteConfigByoPanel(unittest.TestCase):
    """InviteConfigByoPanel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InviteConfigByoPanel:
        """Test InviteConfigByoPanel
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InviteConfigByoPanel`
        """
        model = InviteConfigByoPanel()
        if include_optional:
            return InviteConfigByoPanel(
                kind = 'BYO_PANEL',
                byo_panel_config = keplar_api.models.byo_panel_repdata_config.ByoPanelRepdataConfig(
                    kind = 'REPDATA', 
                    selected_qualifications = [
                        keplar_api.models.repdata_qualification.RepdataQualification(
                            question_id = 1.337, 
                            allowed_option_ids = [
                                null
                                ], )
                        ], ),
                title = '',
                description = '',
                max_responses = 1.337,
                max_responses_per_participant = 1.337,
                video_recording = keplar_api.models.video_recording_settings.VideoRecordingSettings(
                    enabled = True, 
                    include_audio = True, )
            )
        else:
            return InviteConfigByoPanel(
                kind = 'BYO_PANEL',
                byo_panel_config = keplar_api.models.byo_panel_repdata_config.ByoPanelRepdataConfig(
                    kind = 'REPDATA', 
                    selected_qualifications = [
                        keplar_api.models.repdata_qualification.RepdataQualification(
                            question_id = 1.337, 
                            allowed_option_ids = [
                                null
                                ], )
                        ], ),
                title = '',
        )
        """

    def testInviteConfigByoPanel(self):
        """Test InviteConfigByoPanel"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from keplar_api.models.video_recording_settings import VideoRecordingSettings
from typing import Optional, Set
from typing_extensions import Self

class CodeInviteConfigContacts(BaseModel):
    """
    CodeInviteConfigContacts
    """ # noqa: E501
    kind: StrictStr
    is_test: Optional[StrictBool] = Field(default=None, alias="isTest")
    show_call_metadata: Optional[StrictBool] = Field(default=None, alias="showCallMetadata")
    title: StrictStr
    description: Optional[StrictStr] = None
    max_responses: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maxResponses")
    max_responses_per_participant: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maxResponsesPerParticipant")
    video_recording: Optional[VideoRecordingSettings] = Field(default=None, alias="videoRecording")
    __properties: ClassVar[List[str]] = ["kind", "isTest", "showCallMetadata", "title", "description", "maxResponses", "maxResponsesPerParticipant", "videoRecording"]

    @field_validator('kind')
    def kind_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['CONTACTS']):
            raise ValueError("must be one of enum values ('CONTACTS')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CodeInviteConfigContacts from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of video_recording
        if self.video_recording:
            _dict['videoRecording'] = self.video_recording.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CodeInviteConfigContacts from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "kind": obj.get("kind"),
            "isTest": obj.get("isTest"),
            "showCallMetadata": obj.get("showCallMetadata"),
            "title": obj.get("title"),
            "description": obj.get("description"),
            "maxResponses": obj.get("maxResponses"),
            "maxResponsesPerParticipant": obj.get("maxResponsesPerParticipant"),
            "videoRecording": VideoRecordingSettings.from_dict(obj["videoRecording"]) if obj.get("videoRecording") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.artifact_data_not_null import ArtifactDataNotNull

class TestArtifactDataNotNull(unittest.TestCase):
    """ArtifactDataNotNull unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ArtifactDataNotNull:
        """Test ArtifactDataNotNull
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ArtifactDataNotNull`
        """
        model = ArtifactDataNotNull()
        if include_optional:
            return ArtifactDataNotNull(
                kind = 'presentation',
                data = keplar_api.models.artifact_data_thematic_analysis_data.ArtifactDataThematicAnalysis_data(
                    query = '', 
                    summary = '', 
                    themes = [
                        keplar_api.models.artifact_data_thematic_analysis_data_themes_inner.ArtifactDataThematicAnalysis_data_themes_inner(
                            label = '', 
                            description = '', )
                        ], ),
                report = '',
                references = {
                    'key' : ''
                    },
                call_ids = [
                    ''
                    ],
                projects = [
                    keplar_api.models.artifact_data_report_projects_inner.ArtifactDataReport_projects_inner(
                        id = '', 
                        name = '', 
                        participants = 1.337, )
                    ],
                thread_id = '',
                query = '',
                source_report_artifact_id = '',
                config = keplar_api.models.presentation_config.PresentationConfig(
                    text_amount = 'brief', 
                    image_source = 'aiGenerated', 
                    num_cards = 1.337, 
                    dimensions = 'fluid', 
                    additional_instructions = '', ),
                gamma_generation_id = '',
                gamma_url = '',
                export_url = ''
            )
        else:
            return ArtifactDataNotNull(
                kind = 'presentation',
                data = keplar_api.models.artifact_data_thematic_analysis_data.ArtifactDataThematicAnalysis_data(
                    query = '', 
                    summary = '', 
                    themes = [
                        keplar_api.models.artifact_data_thematic_analysis_data_themes_inner.ArtifactDataThematicAnalysis_data_themes_inner(
                            label = '', 
                            description = '', )
                        ], ),
                report = '',
                references = {
                    'key' : ''
                    },
                call_ids = [
                    ''
                    ],
                source_report_artifact_id = '',
                config = keplar_api.models.presentation_config.PresentationConfig(
                    text_amount = 'brief', 
                    image_source = 'aiGenerated', 
                    num_cards = 1.337, 
                    dimensions = 'fluid', 
                    additional_instructions = '', ),
        )
        """

    def testArtifactDataNotNull(self):
        """Test ArtifactDataNotNull"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from keplar_api.models.call_kind import CallKind
from keplar_api.models.call_metadata import CallMetadata
from keplar_api.models.call_status import CallStatus
from typing import Optional, Set
from typing_extensions import Self

class Call(BaseModel):
    """
    Call
    """ # noqa: E501
    id: StrictStr
    vendor: StrictStr
    vendor_call_id: Optional[StrictStr] = Field(default=None, alias="vendorCallId")
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    started_at: Optional[datetime] = Field(default=None, alias="startedAt")
    ended_at: Optional[datetime] = Field(default=None, alias="endedAt")
    duration_ms: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="durationMs")
    kind: Optional[CallKind] = None
    status: Optional[CallStatus] = None
    phone_number: Optional[StrictStr] = Field(default=None, alias="phoneNumber")
    metadata: Optional[CallMetadata] = None
    invite_response_id: StrictStr = Field(alias="inviteResponseId")
    participant_id: Optional[StrictStr] = Field(default=None, alias="participantId")
    invite_id: Optional[StrictStr] = Field(default=None, alias="inviteId")
    analysis: Optional[Any] = None
    invite_response: Optional[InviteResponse] = Field(default=None, alias="inviteResponse")
    events: Optional[List[CallEvent]] = None
    participant: Optional[Participant] = None
    invite: Optional[Invite] = None
    conversation_messages: Optional[List[ConversationMessage]] = Field(default=None, alias="conversationMessages")
    conversation_message_topics: Optional[List[ConversationMessageTopic]] = Field(default=None, alias="conversationMessageTopics")
    __properties: ClassVar[List[str]] = ["id", "vendor", "vendorCallId", "createdAt", "updatedAt", "startedAt", "endedAt", "durationMs", "kind", "status", "phoneNumber", "metadata", "inviteResponseId", "participantId", "inviteId", "analysis", "inviteResponse", "events", "participant", "invite", "conversationMessages", "conversationMessageTopics"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Call from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict['metadata'] = self.metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of invite_response
        if self.invite_response:
            _dict['inviteResponse'] = self.invite_response.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in events (list)
        _items = []
        if self.events:
            for _item_events in self.events:
                if _item_events:
                    _items.append(_item_events.to_dict())
            _dict['events'] = _items
        # override the default output from pydantic by calling `to_dict()` of participant
        if self.participant:
            _dict['participant'] = self.participant.to_dict()
        # override the default output from pydantic by calling `to_dict()` of invite
        if self.invite:
            _dict['invite'] = self.invite.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in conversation_messages (list)
        _items = []
        if self.conversation_messages:
            for _item_conversation_messages in self.conversation_messages:
                if _item_conversation_messages:
                    _items.append(_item_conversation_messages.to_dict())
            _dict['conversationMessages'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in conversation_message_topics (list)
        _items = []
        if self.conversation_message_topics:
            for _item_conversation_message_topics in self.conversation_message_topics:
                if _item_conversation_message_topics:
                    _items.append(_item_conversation_message_topics.to_dict())
            _dict['conversationMessageTopics'] = _items
        # set to None if vendor_call_id (nullable) is None
        # and model_fields_set contains the field
        if self.vendor_call_id is None and "vendor_call_id" in self.model_fields_set:
            _dict['vendorCallId'] = None

        # set to None if started_at (nullable) is None
        # and model_fields_set contains the field
        if self.started_at is None and "started_at" in self.model_fields_set:
            _dict['startedAt'] = None

        # set to None if ended_at (nullable) is None
        # and model_fields_set contains the field
        if self.ended_at is None and "ended_at" in self.model_fields_set:
            _dict['endedAt'] = None

        # set to None if duration_ms (nullable) is None
        # and model_fields_set contains the field
        if self.duration_ms is None and "duration_ms" in self.model_fields_set:
            _dict['durationMs'] = None

        # set to None if kind (nullable) is None
        # and model_fields_set contains the field
        if self.kind is None and "kind" in self.model_fields_set:
            _dict['kind'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if phone_number (nullable) is None
        # and model_fields_set contains the field
        if self.phone_number is None and "phone_number" in self.model_fields_set:
            _dict['phoneNumber'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        # set to None if participant_id (nullable) is None
        # and model_fields_set contains the field
        if self.participant_id is None and "participant_id" in self.model_fields_set:
            _dict['participantId'] = None

        # set to None if invite_id (nullable) is None
        # and model_fields_set contains the field
        if self.invite_id is None and "invite_id" in self.model_fields_set:
            _dict['inviteId'] = None

        # set to None if analysis (nullable) is None
        # and model_fields_set contains the field
        if self.analysis is None and "analysis" in self.model_fields_set:
            _dict['analysis'] = None

        # set to None if participant (nullable) is None
        # and model_fields_set contains the field
        if self.participant is None and "participant" in self.model_fields_set:
            _dict['participant'] = None

        # set to None if invite (nullable) is None
        # and model_fields_set contains the field
        if self.invite is None and "invite" in self.model_fields_set:
            _dict['invite'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Call from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "vendor": obj.get("vendor"),
            "vendorCallId": obj.get("vendorCallId"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "startedAt": obj.get("startedAt"),
            "endedAt": obj.get("endedAt"),
            "durationMs": obj.get("durationMs"),
            "kind": obj.get("kind"),
            "status": obj.get("status"),
            "phoneNumber": obj.get("phoneNumber"),
            "metadata": CallMetadata.from_dict(obj["metadata"]) if obj.get("metadata") is not None else None,
            "inviteResponseId": obj.get("inviteResponseId"),
            "participantId": obj.get("participantId"),
            "inviteId": obj.get("inviteId"),
            "analysis": obj.get("analysis"),
            "inviteResponse": InviteResponse.from_dict(obj["inviteResponse"]) if obj.get("inviteResponse") is not None else None,
            "events": [CallEvent.from_dict(_item) for _item in obj["events"]] if obj.get("events") is not None else None,
            "participant": Participant.from_dict(obj["participant"]) if obj.get("participant") is not None else None,
            "invite": Invite.from_dict(obj["invite"]) if obj.get("invite") is not None else None,
            "conversationMessages": [ConversationMessage.from_dict(_item) for _item in obj["conversationMessages"]] if obj.get("conversationMessages") is not None else None,
            "conversationMessageTopics": [ConversationMessageTopic.from_dict(_item) for _item in obj["conversationMessageTopics"]] if obj.get("conversationMessageTopics") is not None else None
        })
        return _obj

from keplar_api.models.call_event import CallEvent
from keplar_api.models.conversation_message import ConversationMessage
from keplar_api.models.conversation_message_topic import ConversationMessageTopic
from keplar_api.models.invite import Invite
from keplar_api.models.invite_response import InviteResponse
from keplar_api.models.participant import Participant
# TODO: Rewrite to not use raise_errors
Call.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.save_search_request import SaveSearchRequest

class TestSaveSearchRequest(unittest.TestCase):
    """SaveSearchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SaveSearchRequest:
        """Test SaveSearchRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SaveSearchRequest`
        """
        model = SaveSearchRequest()
        if include_optional:
            return SaveSearchRequest(
                title = '0',
                description = '',
                tabs = [
                    keplar_api.models.save_search_request_tabs_inner.saveSearch_request_tabs_inner(
                        id = '', 
                        query = '', 
                        project_ids = [
                            ''
                            ], 
                        total_results = 1.337, 
                        messages = [
                            keplar_api.models.analyze_notebook_200_response_search_results_messages_inner.analyzeNotebook_200_response_searchResults_messages_inner(
                                project_id = '', 
                                call_id = '', 
                                recording_url = '', 
                                message_index = 1.337, 
                                message = '', 
                                score = 1.337, 
                                project_name = '', 
                                context_messages = [
                                    keplar_api.models.analyze_notebook_200_response_search_results_messages_inner_context_messages_inner.analyzeNotebook_200_response_searchResults_messages_inner_contextMessages_inner(
                                        role = '', 
                                        message = '', 
                                        index = 1.337, 
                                        seconds_from_start = 1.337, 
                                        duration = 1.337, )
                                    ], )
                            ], )
                    ]
            )
        else:
            return SaveSearchRequest(
                title = '0',
                tabs = [
                    keplar_api.models.save_search_request_tabs_inner.saveSearch_request_tabs_inner(
                        id = '', 
                        query = '', 
                        project_ids = [
                            ''
                            ], 
                        total_results = 1.337, 
                        messages = [
                            keplar_api.models.analyze_notebook_200_response_search_results_messages_inner.analyzeNotebook_200_response_searchResults_messages_inner(
                                project_id = '', 
                                call_id = '', 
                                recording_url = '', 
                                message_index = 1.337, 
                                message = '', 
                                score = 1.337, 
                                project_name = '', 
                                context_messages = [
                                    keplar_api.models.analyze_notebook_200_response_search_results_messages_inner_context_messages_inner.analyzeNotebook_200_response_searchResults_messages_inner_contextMessages_inner(
                                        role = '', 
                                        message = '', 
                                        index = 1.337, 
                                        seconds_from_start = 1.337, 
                                        duration = 1.337, )
                                    ], )
                            ], )
                    ],
        )
        """

    def testSaveSearchRequest(self):
        """Test SaveSearchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.project_analysis_report import ProjectAnalysisReport

class TestProjectAnalysisReport(unittest.TestCase):
    """ProjectAnalysisReport unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProjectAnalysisReport:
        """Test ProjectAnalysisReport
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProjectAnalysisReport`
        """
        model = ProjectAnalysisReport()
        if include_optional:
            return ProjectAnalysisReport(
                markdown_report = '',
                structured_report = None,
                call_ids = [
                    ''
                    ],
                references = {
                    'key' : ''
                    }
            )
        else:
            return ProjectAnalysisReport(
                markdown_report = '',
                call_ids = [
                    ''
                    ],
                references = {
                    'key' : ''
                    },
        )
        """

    def testProjectAnalysisReport(self):
        """Test ProjectAnalysisReport"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.api_projects_post_request_thread_assets_inner import ApiProjectsPostRequestThreadAssetsInner
from keplar_api.models.project_config import ProjectConfig
from keplar_api.models.project_conversation_config import ProjectConversationConfig
from keplar_api.models.project_status import ProjectStatus
from typing import Optional, Set
from typing_extensions import Self

class ApiProjectsPostRequest(BaseModel):
    """
    ApiProjectsPostRequest
    """ # noqa: E501
    name: StrictStr
    description: Optional[StrictStr] = None
    status: Optional[ProjectStatus] = None
    config: ProjectConfig
    conversation_config: ProjectConversationConfig = Field(alias="conversationConfig")
    thread_assets: Optional[List[ApiProjectsPostRequestThreadAssetsInner]] = Field(default=None, alias="threadAssets")
    thread_id: Optional[StrictStr] = Field(default=None, alias="threadId")
    __properties: ClassVar[List[str]] = ["name", "description", "status", "config", "conversationConfig", "threadAssets", "threadId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiProjectsPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of config
        if self.config:
            _dict['config'] = self.config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of conversation_config
        if self.conversation_config:
            _dict['conversationConfig'] = self.conversation_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in thread_assets (list)
        _items = []
        if self.thread_assets:
            for _item_thread_assets in self.thread_assets:
                if _item_thread_assets:
                    _items.append(_item_thread_assets.to_dict())
            _dict['threadAssets'] = _items
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiProjectsPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "status": obj.get("status"),
            "config": ProjectConfig.from_dict(obj["config"]) if obj.get("config") is not None else None,
            "conversationConfig": ProjectConversationConfig.from_dict(obj["conversationConfig"]) if obj.get("conversationConfig") is not None else None,
            "threadAssets": [ApiProjectsPostRequestThreadAssetsInner.from_dict(_item) for _item in obj["threadAssets"]] if obj.get("threadAssets") is not None else None,
            "threadId": obj.get("threadId")
        })
        return _obj





# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.project_audience import ProjectAudience

class TestProjectAudience(unittest.TestCase):
    """ProjectAudience unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProjectAudience:
        """Test ProjectAudience
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProjectAudience`
        """
        model = ProjectAudience()
        if include_optional:
            return ProjectAudience(
                sample_size = 1.337,
                invite_title = '',
                invite_description = '',
                participants = [
                    keplar_api.models.participant_create.ParticipantCreate(
                        id = '', 
                        name = '', 
                        email = '', 
                        phone_number = '01234', 
                        data = keplar_api.models.data.data(), )
                    ],
                panel_settings = keplar_api.models.panel_settings.PanelSettings(
                    respondent_attributes = [
                        keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                            qualifications = [
                                keplar_api.models.panel_qualification.PanelQualification(
                                    allowed_option_ids = [
                                        null
                                        ], 
                                    question_id = 1.337, )
                                ], 
                            quota = 1.337, 
                            quota_name = '', )
                        ], 
                    country_code = '', 
                    language_code = '', 
                    length_of_interview = 1.337, 
                    incidence_rate = 1.337, 
                    compensation = 1.337, ),
                use_public_link = True
            )
        else:
            return ProjectAudience(
                sample_size = 1.337,
        )
        """

    def testProjectAudience(self):
        """Test ProjectAudience"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.artifact_data_thematic_analysis_data import ArtifactDataThematicAnalysisData

class TestArtifactDataThematicAnalysisData(unittest.TestCase):
    """ArtifactDataThematicAnalysisData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ArtifactDataThematicAnalysisData:
        """Test ArtifactDataThematicAnalysisData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ArtifactDataThematicAnalysisData`
        """
        model = ArtifactDataThematicAnalysisData()
        if include_optional:
            return ArtifactDataThematicAnalysisData(
                query = '',
                summary = '',
                themes = [
                    keplar_api.models.artifact_data_thematic_analysis_data_themes_inner.ArtifactDataThematicAnalysis_data_themes_inner(
                        label = '', 
                        description = '', )
                    ]
            )
        else:
            return ArtifactDataThematicAnalysisData(
                summary = '',
                themes = [
                    keplar_api.models.artifact_data_thematic_analysis_data_themes_inner.ArtifactDataThematicAnalysis_data_themes_inner(
                        label = '', 
                        description = '', )
                    ],
        )
        """

    def testArtifactDataThematicAnalysisData(self):
        """Test ArtifactDataThematicAnalysisData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.create_project_share_response import CreateProjectShareResponse

class TestCreateProjectShareResponse(unittest.TestCase):
    """CreateProjectShareResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateProjectShareResponse:
        """Test CreateProjectShareResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateProjectShareResponse`
        """
        model = CreateProjectShareResponse()
        if include_optional:
            return CreateProjectShareResponse(
                share_token = '',
                share_url = '',
                share_entity = keplar_api.models.share_entity.ShareEntity(
                    id = '', 
                    token = '', 
                    entity_kind = 'project', 
                    entity_id = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    access_count = 1.337, 
                    is_active = True, 
                    created_by_kind = 'participant', 
                    created_by_id = '', 
                    config = null, 
                    email_shares = [
                        keplar_api.models.email_share.EmailShare(
                            id = '', 
                            email = '', 
                            share_entity_id = '', 
                            access_token = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            accessed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            share_entity = keplar_api.models.share_entity.ShareEntity(
                                id = '', 
                                token = '', 
                                entity_kind = 'project', 
                                entity_id = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                access_count = 1.337, 
                                is_active = True, 
                                created_by_id = '', 
                                config = null, ), )
                        ], )
            )
        else:
            return CreateProjectShareResponse(
                share_token = '',
                share_url = '',
                share_entity = keplar_api.models.share_entity.ShareEntity(
                    id = '', 
                    token = '', 
                    entity_kind = 'project', 
                    entity_id = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    access_count = 1.337, 
                    is_active = True, 
                    created_by_kind = 'participant', 
                    created_by_id = '', 
                    config = null, 
                    email_shares = [
                        keplar_api.models.email_share.EmailShare(
                            id = '', 
                            email = '', 
                            share_entity_id = '', 
                            access_token = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            accessed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            share_entity = keplar_api.models.share_entity.ShareEntity(
                                id = '', 
                                token = '', 
                                entity_kind = 'project', 
                                entity_id = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                access_count = 1.337, 
                                is_active = True, 
                                created_by_id = '', 
                                config = null, ), )
                        ], ),
        )
        """

    def testCreateProjectShareResponse(self):
        """Test CreateProjectShareResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Union
from keplar_api.models.repdata_survey_redirects import RepdataSurveyRedirects
from typing import Optional, Set
from typing_extensions import Self

class RepdataSurveyAttributes(BaseModel):
    """
    RepdataSurveyAttributes
    """ # noqa: E501
    respondents: Union[StrictFloat, StrictInt]
    country_code: StrictStr
    language_code: StrictStr
    length_of_interview: Union[StrictFloat, StrictInt]
    incidence_rate: Union[StrictFloat, StrictInt]
    minimum_price_per_complete: Union[StrictFloat, StrictInt]
    offered_price_per_complete: Union[StrictFloat, StrictInt]
    device_compatibilities: List[StrictStr]
    collects_pii: StrictBool
    hashing_enabled: StrictBool
    calculation_type: StrictStr
    traffic_control_limit_type: StrictStr
    out_of_field_date: StrictStr
    out_of_field_timezone: StrictStr
    entry_link: StrictStr
    redirects: RepdataSurveyRedirects
    __properties: ClassVar[List[str]] = ["respondents", "country_code", "language_code", "length_of_interview", "incidence_rate", "minimum_price_per_complete", "offered_price_per_complete", "device_compatibilities", "collects_pii", "hashing_enabled", "calculation_type", "traffic_control_limit_type", "out_of_field_date", "out_of_field_timezone", "entry_link", "redirects"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RepdataSurveyAttributes from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of redirects
        if self.redirects:
            _dict['redirects'] = self.redirects.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RepdataSurveyAttributes from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "respondents": obj.get("respondents"),
            "country_code": obj.get("country_code"),
            "language_code": obj.get("language_code"),
            "length_of_interview": obj.get("length_of_interview"),
            "incidence_rate": obj.get("incidence_rate"),
            "minimum_price_per_complete": obj.get("minimum_price_per_complete"),
            "offered_price_per_complete": obj.get("offered_price_per_complete"),
            "device_compatibilities": obj.get("device_compatibilities"),
            "collects_pii": obj.get("collects_pii"),
            "hashing_enabled": obj.get("hashing_enabled"),
            "calculation_type": obj.get("calculation_type"),
            "traffic_control_limit_type": obj.get("traffic_control_limit_type"),
            "out_of_field_date": obj.get("out_of_field_date"),
            "out_of_field_timezone": obj.get("out_of_field_timezone"),
            "entry_link": obj.get("entry_link"),
            "redirects": RepdataSurveyRedirects.from_dict(obj["redirects"]) if obj.get("redirects") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.inline_node import InlineNode

class TestInlineNode(unittest.TestCase):
    """InlineNode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InlineNode:
        """Test InlineNode
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InlineNode`
        """
        model = InlineNode()
        if include_optional:
            return InlineNode(
                type = 'text',
                text = '',
                marks = [
                    keplar_api.models.mark.Mark()
                    ],
                attrs = keplar_api.models.mention_node_attrs.MentionNodeAttrs(
                    id = '', 
                    label = '', 
                    type = 'asset', )
            )
        else:
            return InlineNode(
                type = 'text',
                text = '',
        )
        """

    def testInlineNode(self):
        """Test InlineNode"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.invite_response_evaluation_metadata import InviteResponseEvaluationMetadata

class TestInviteResponseEvaluationMetadata(unittest.TestCase):
    """InviteResponseEvaluationMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InviteResponseEvaluationMetadata:
        """Test InviteResponseEvaluationMetadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InviteResponseEvaluationMetadata`
        """
        model = InviteResponseEvaluationMetadata()
        if include_optional:
            return InviteResponseEvaluationMetadata(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                original_evaluation = 'SYSTEM_PASS',
                previous_evaluation = 'SYSTEM_PASS',
                created_by = '',
                notes = '',
                transcript_quality = 'HIGH'
            )
        else:
            return InviteResponseEvaluationMetadata(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testInviteResponseEvaluationMetadata(self):
        """Test InviteResponseEvaluationMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.analyze_notebook200_response_search_results_messages_inner_context_messages_inner import AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner

class TestAnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner(unittest.TestCase):
    """AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner:
        """Test AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner`
        """
        model = AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner()
        if include_optional:
            return AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner(
                role = '',
                message = '',
                index = 1.337,
                seconds_from_start = 1.337,
                duration = 1.337
            )
        else:
            return AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner(
                role = '',
                message = '',
                index = 1.337,
        )
        """

    def testAnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner(self):
        """Test AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.code_invite_config_contacts import CodeInviteConfigContacts

class TestCodeInviteConfigContacts(unittest.TestCase):
    """CodeInviteConfigContacts unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CodeInviteConfigContacts:
        """Test CodeInviteConfigContacts
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CodeInviteConfigContacts`
        """
        model = CodeInviteConfigContacts()
        if include_optional:
            return CodeInviteConfigContacts(
                kind = 'CONTACTS',
                is_test = True,
                show_call_metadata = True,
                title = '',
                description = '',
                max_responses = 1.337,
                max_responses_per_participant = 1.337,
                video_recording = keplar_api.models.video_recording_settings.VideoRecordingSettings(
                    enabled = True, 
                    include_audio = True, )
            )
        else:
            return CodeInviteConfigContacts(
                kind = 'CONTACTS',
                title = '',
        )
        """

    def testCodeInviteConfigContacts(self):
        """Test CodeInviteConfigContacts"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
